"""Definitions for color constants.
"""

from typing_extensions import Final

from apysc._color.color import Color
from apysc._color.get_colors_members_mixin import GetColorsMenmbersMixIn

_000000: Final[Color] = Color("#000000")
_111111: Final[Color] = Color("#111111")
_222222: Final[Color] = Color("#222222")
_333333: Final[Color] = Color("#333333")
_444444: Final[Color] = Color("#444444")
_555555: Final[Color] = Color("#555555")
_666666: Final[Color] = Color("#666666")
_777777: Final[Color] = Color("#777777")
_888888: Final[Color] = Color("#888888")
_999999: Final[Color] = Color("#999999")
_AAAAAA: Final[Color] = Color("#aaaaaa")
_BBBBBB: Final[Color] = Color("#bbbbbb")
_CCCCCC: Final[Color] = Color("#cccccc")
_DDDDDD: Final[Color] = Color("#dddddd")
_EEEEEE: Final[Color] = Color("#eeeeee")
_FFFFFF: Final[Color] = Color("#ffffff")
_FF0000: Final[Color] = Color("#ff0000")
_0000FF: Final[Color] = Color("#0000ff")
_ADD8E6: Final[Color] = Color("#add8e6")
_00008B: Final[Color] = Color("#00008b")
_FFFF00: Final[Color] = Color("#ffff00")
_00FFFF: Final[Color] = Color("#00ffff")
_FF00FF: Final[Color] = Color("#ff00ff")
_800080: Final[Color] = Color("#800080")
_00FF00: Final[Color] = Color("#00ff00")
_008000: Final[Color] = Color("#008000")
_808000: Final[Color] = Color("#808000")
_00AAFF: Final[Color] = Color("#00aaff")
_FFC0CB: Final[Color] = Color("#ffc0cb")
_C0C0C0: Final[Color] = Color("#c0c0c0")
_FFA500: Final[Color] = Color("#ffa500")
_A52A2A: Final[Color] = Color("#a52a2a")
_800000: Final[Color] = Color("#800000")
_7FFFD4: Final[Color] = Color("#7fffd4")
_0C090A: Final[Color] = Color("#0c090a")
_34282C: Final[Color] = Color("#34282c")
_3B3131: Final[Color] = Color("#3b3131")
_3A3B3C: Final[Color] = Color("#3a3b3c")
_454545: Final[Color] = Color("#454545")
_413839: Final[Color] = Color("#413839")
_3D3C3A: Final[Color] = Color("#3d3c3a")
_463E3F: Final[Color] = Color("#463e3f")
_4C4646: Final[Color] = Color("#4c4646")
_504A4B: Final[Color] = Color("#504a4b")
_565051: Final[Color] = Color("#565051")
_52595D: Final[Color] = Color("#52595d")
_5C5858: Final[Color] = Color("#5c5858")
_625D5D: Final[Color] = Color("#625d5d")
_666362: Final[Color] = Color("#666362")
_696969: Final[Color] = Color("#696969")
_686A6C: Final[Color] = Color("#686a6c")
_6D6968: Final[Color] = Color("#6d6968")
_726E6D: Final[Color] = Color("#726e6d")
_736F6E: Final[Color] = Color("#736f6e")
_757575: Final[Color] = Color("#757575")
_797979: Final[Color] = Color("#797979")
_837E7C: Final[Color] = Color("#837e7c")
_808080: Final[Color] = Color("#808080")
_848482: Final[Color] = Color("#848482")
_8D918D: Final[Color] = Color("#8d918d")
_A9A9A9: Final[Color] = Color("#a9a9a9")
_B6B6B4: Final[Color] = Color("#b6b6b4")
_C9C0BB: Final[Color] = Color("#c9c0bb")
_D1D0CE: Final[Color] = Color("#d1d0ce")
_CECECE: Final[Color] = Color("#cecece")
_D3D3D3: Final[Color] = Color("#d3d3d3")
_DADBDD: Final[Color] = Color("#dadbdd")
_DCDCDC: Final[Color] = Color("#dcdcdc")
_E5E4E2: Final[Color] = Color("#e5e4e2")
_BCC6CC: Final[Color] = Color("#bcc6cc")
_98AFC7: Final[Color] = Color("#98afc7")
_838996: Final[Color] = Color("#838996")
_778899: Final[Color] = Color("#778899")
_708090: Final[Color] = Color("#708090")
_657383: Final[Color] = Color("#657383")
_616D7E: Final[Color] = Color("#616d7e")
_646D7E: Final[Color] = Color("#646d7e")
_566D7E: Final[Color] = Color("#566d7e")
_737CA1: Final[Color] = Color("#737ca1")
_728FCE: Final[Color] = Color("#728fce")
_4863A0: Final[Color] = Color("#4863a0")
_2F539B: Final[Color] = Color("#2f539b")
_2B547E: Final[Color] = Color("#2b547e")
_36454F: Final[Color] = Color("#36454f")
_29465B: Final[Color] = Color("#29465b")
_2B3856: Final[Color] = Color("#2b3856")
_123456: Final[Color] = Color("#123456")
_151B54: Final[Color] = Color("#151b54")
_191970: Final[Color] = Color("#191970")
_000080: Final[Color] = Color("#000080")
_151B8D: Final[Color] = Color("#151b8d")
_15317E: Final[Color] = Color("#15317e")
_0000A0: Final[Color] = Color("#0000a0")
_0000A5: Final[Color] = Color("#0000a5")
_0020C2: Final[Color] = Color("#0020c2")
_0000CD: Final[Color] = Color("#0000cd")
_0041C2: Final[Color] = Color("#0041c2")
_2916F5: Final[Color] = Color("#2916f5")
_0002FF: Final[Color] = Color("#0002ff")
_0909FF: Final[Color] = Color("#0909ff")
_1F45FC: Final[Color] = Color("#1f45fc")
_2554C7: Final[Color] = Color("#2554c7")
_1569C7: Final[Color] = Color("#1569c7")
_1974D2: Final[Color] = Color("#1974d2")
_2B60DE: Final[Color] = Color("#2b60de")
_4169E1: Final[Color] = Color("#4169e1")
_2B65EC: Final[Color] = Color("#2b65ec")
_306EFF: Final[Color] = Color("#306eff")
_157DEC: Final[Color] = Color("#157dec")
_1589FF: Final[Color] = Color("#1589ff")
_1E90FF: Final[Color] = Color("#1e90ff")
_368BC1: Final[Color] = Color("#368bc1")
_4682B4: Final[Color] = Color("#4682b4")
_488AC7: Final[Color] = Color("#488ac7")
_3090C7: Final[Color] = Color("#3090c7")
_659EC7: Final[Color] = Color("#659ec7")
_87AFC7: Final[Color] = Color("#87afc7")
_95B9C7: Final[Color] = Color("#95b9c7")
_6495ED: Final[Color] = Color("#6495ed")
_6698FF: Final[Color] = Color("#6698ff")
_56A5EC: Final[Color] = Color("#56a5ec")
_38ACEC: Final[Color] = Color("#38acec")
_00BFFF: Final[Color] = Color("#00bfff")
_3BB9FF: Final[Color] = Color("#3bb9ff")
_5CB3FF: Final[Color] = Color("#5cb3ff")
_79BAEC: Final[Color] = Color("#79baec")
_82CAFF: Final[Color] = Color("#82caff")
_87CEFA: Final[Color] = Color("#87cefa")
_87CEEB: Final[Color] = Color("#87ceeb")
_A0CFEC: Final[Color] = Color("#a0cfec")
_B7CEEC: Final[Color] = Color("#b7ceec")
_B4CFEC: Final[Color] = Color("#b4cfec")
_ADDFFF: Final[Color] = Color("#addfff")
_C2DFFF: Final[Color] = Color("#c2dfff")
_C6DEFF: Final[Color] = Color("#c6deff")
_BDEDFF: Final[Color] = Color("#bdedff")
_B0E0E6: Final[Color] = Color("#b0e0e6")
_AFDCEC: Final[Color] = Color("#afdcec")
_B0CFDE: Final[Color] = Color("#b0cfde")
_C9DFEC: Final[Color] = Color("#c9dfec")
_D5D6EA: Final[Color] = Color("#d5d6ea")
_E3E4FA: Final[Color] = Color("#e3e4fa")
_DBE9FA: Final[Color] = Color("#dbe9fa")
_E6E6FA: Final[Color] = Color("#e6e6fa")
_EBF4FA: Final[Color] = Color("#ebf4fa")
_F0F8FF: Final[Color] = Color("#f0f8ff")
_F8F8FF: Final[Color] = Color("#f8f8ff")
_F0FFFF: Final[Color] = Color("#f0ffff")
_E0FFFF: Final[Color] = Color("#e0ffff")
_CCFFFF: Final[Color] = Color("#ccffff")
_9AFEFF: Final[Color] = Color("#9afeff")
_7DFDFE: Final[Color] = Color("#7dfdfe")
_57FEFF: Final[Color] = Color("#57feff")
_0AFFFF: Final[Color] = Color("#0affff")
_50EBEC: Final[Color] = Color("#50ebec")
_4EE2EC: Final[Color] = Color("#4ee2ec")
_16E2F5: Final[Color] = Color("#16e2f5")
_8EEBEC: Final[Color] = Color("#8eebec")
_AFEEEE: Final[Color] = Color("#afeeee")
_CFECEC: Final[Color] = Color("#cfecec")
_B3D9D9: Final[Color] = Color("#b3d9d9")
_77BFC7: Final[Color] = Color("#77bfc7")
_92C7C7: Final[Color] = Color("#92c7c7")
_78C7C7: Final[Color] = Color("#78c7c7")
_7BCCB5: Final[Color] = Color("#7bccb5")
_66CDAA: Final[Color] = Color("#66cdaa")
_AAF0D1: Final[Color] = Color("#aaf0d1")
_93FFE8: Final[Color] = Color("#93ffe8")
_01F9C6: Final[Color] = Color("#01f9c6")
_40E0D0: Final[Color] = Color("#40e0d0")
_48D1CC: Final[Color] = Color("#48d1cc")
_48CCCD: Final[Color] = Color("#48cccd")
_46C7C7: Final[Color] = Color("#46c7c7")
_43C6DB: Final[Color] = Color("#43c6db")
_00CED1: Final[Color] = Color("#00ced1")
_43BFC7: Final[Color] = Color("#43bfc7")
_20B2AA: Final[Color] = Color("#20b2aa")
_3EA99F: Final[Color] = Color("#3ea99f")
_5F9EA0: Final[Color] = Color("#5f9ea0")
_3B9C9C: Final[Color] = Color("#3b9c9c")
_008B8B: Final[Color] = Color("#008b8b")
_00827F: Final[Color] = Color("#00827f")
_008080: Final[Color] = Color("#008080")
_007C80: Final[Color] = Color("#007c80")
_045F5F: Final[Color] = Color("#045f5f")
_045D5D: Final[Color] = Color("#045d5d")
_033E3E: Final[Color] = Color("#033e3e")
_25383C: Final[Color] = Color("#25383c")
_2C3539: Final[Color] = Color("#2c3539")
_3C565B: Final[Color] = Color("#3c565b")
_4C787E: Final[Color] = Color("#4c787e")
_5E7D7E: Final[Color] = Color("#5e7d7e")
_307D7E: Final[Color] = Color("#307d7e")
_348781: Final[Color] = Color("#348781")
_438D80: Final[Color] = Color("#438d80")
_4E8975: Final[Color] = Color("#4e8975")
_1F6357: Final[Color] = Color("#1f6357")
_306754: Final[Color] = Color("#306754")
_006A4E: Final[Color] = Color("#006a4e")
_2E8B57: Final[Color] = Color("#2e8b57")
_1B8A6B: Final[Color] = Color("#1b8a6b")
_31906E: Final[Color] = Color("#31906e")
_00A36C: Final[Color] = Color("#00a36c")
_34A56F: Final[Color] = Color("#34a56f")
_1AA260: Final[Color] = Color("#1aa260")
_50C878: Final[Color] = Color("#50c878")
_3EB489: Final[Color] = Color("#3eb489")
_3CB371: Final[Color] = Color("#3cb371")
_7C9D8E: Final[Color] = Color("#7c9d8e")
_78866B: Final[Color] = Color("#78866b")
_848B79: Final[Color] = Color("#848b79")
_617C58: Final[Color] = Color("#617c58")
_728C00: Final[Color] = Color("#728c00")
_6B8E23: Final[Color] = Color("#6b8e23")
_556B2F: Final[Color] = Color("#556b2f")
_4E5B31: Final[Color] = Color("#4e5b31")
_3A5F0B: Final[Color] = Color("#3a5f0b")
_4B5320: Final[Color] = Color("#4b5320")
_667C26: Final[Color] = Color("#667c26")
_4E9258: Final[Color] = Color("#4e9258")
_08A04B: Final[Color] = Color("#08a04b")
_387C44: Final[Color] = Color("#387c44")
_347235: Final[Color] = Color("#347235")
_347C2C: Final[Color] = Color("#347c2c")
_227442: Final[Color] = Color("#227442")
_228B22: Final[Color] = Color("#228b22")
_006400: Final[Color] = Color("#006400")
_056608: Final[Color] = Color("#056608")
_046307: Final[Color] = Color("#046307")
_355E3B: Final[Color] = Color("#355e3b")
_254117: Final[Color] = Color("#254117")
_004225: Final[Color] = Color("#004225")
_437C17: Final[Color] = Color("#437c17")
_347C17: Final[Color] = Color("#347c17")
_6AA121: Final[Color] = Color("#6aa121")
_8A9A5B: Final[Color] = Color("#8a9a5b")
_3F9B0B: Final[Color] = Color("#3f9b0b")
_4AA02C: Final[Color] = Color("#4aa02c")
_41A317: Final[Color] = Color("#41a317")
_12AD2B: Final[Color] = Color("#12ad2b")
_3EA055: Final[Color] = Color("#3ea055")
_73A16C: Final[Color] = Color("#73a16c")
_6CBB3C: Final[Color] = Color("#6cbb3c")
_6CC417: Final[Color] = Color("#6cc417")
_4CC417: Final[Color] = Color("#4cc417")
_32CD32: Final[Color] = Color("#32cd32")
_52D017: Final[Color] = Color("#52d017")
_4CC552: Final[Color] = Color("#4cc552")
_54C571: Final[Color] = Color("#54c571")
_89C35C: Final[Color] = Color("#89c35c")
_85BB65: Final[Color] = Color("#85bb65")
_99C68E: Final[Color] = Color("#99c68e")
_A0D6B4: Final[Color] = Color("#A0d6b4")
_8FBC8F: Final[Color] = Color("#8fbc8f")
_829F82: Final[Color] = Color("#829f82")
_A2AD9C: Final[Color] = Color("#A2ad9c")
_9CB071: Final[Color] = Color("#9cb071")
_8FB31D: Final[Color] = Color("#8fb31d")
_B0BF1A: Final[Color] = Color("#B0bf1a")
_B2C248: Final[Color] = Color("#B2c248")
_9DC209: Final[Color] = Color("#9dc209")
_A1C935: Final[Color] = Color("#A1c935")
_9ACD32: Final[Color] = Color("#9acd32")
_77DD77: Final[Color] = Color("#77dd77")
_7FE817: Final[Color] = Color("#7fe817")
_59E817: Final[Color] = Color("#59e817")
_57E964: Final[Color] = Color("#57e964")
_16F529: Final[Color] = Color("#16f529")
_5EFB6E: Final[Color] = Color("#5efb6e")
_36F57F: Final[Color] = Color("#36f57f")
_00FF7F: Final[Color] = Color("#00ff7f")
_00FA9A: Final[Color] = Color("#00fa9a")
_5FFB17: Final[Color] = Color("#5ffb17")
_7CFC00: Final[Color] = Color("#7cfc00")
_66FF00: Final[Color] = Color("#66ff00")
_7FFF00: Final[Color] = Color("#7fff00")
_87F717: Final[Color] = Color("#87f717")
_98F516: Final[Color] = Color("#98f516")
_B1FB17: Final[Color] = Color("#B1fb17")
_ADF802: Final[Color] = Color("#adf802")
_ADFF2F: Final[Color] = Color("#adff2f")
_BDF516: Final[Color] = Color("#bdf516")
_DAEE01: Final[Color] = Color("#daee01")
_E2F516: Final[Color] = Color("#e2f516")
_CCFB5D: Final[Color] = Color("#ccfb5d")
_BCE954: Final[Color] = Color("#bce954")
_64E986: Final[Color] = Color("#64e986")
_90EE90: Final[Color] = Color("#90ee90")
_6AFB92: Final[Color] = Color("#6afb92")
_98FB98: Final[Color] = Color("#98fb98")
_98FF98: Final[Color] = Color("#98ff98")
_B5EAAA: Final[Color] = Color("#b5eaaa")
_E3F9A6: Final[Color] = Color("#e3f9a6")
_C3FDB8: Final[Color] = Color("#c3fdb8")
_C2E5D3: Final[Color] = Color("#c2e5d3")
_DBF9DB: Final[Color] = Color("#dbf9db")
_E8F1D4: Final[Color] = Color("#e8f1d4")
_F0FFF0: Final[Color] = Color("#f0fff0")
_F5FFFA: Final[Color] = Color("#f5fffa")
_FFFACD: Final[Color] = Color("#fffacd")
_FFFFC2: Final[Color] = Color("#ffffc2")
_FFFFCC: Final[Color] = Color("#ffffcc")
_FFFDD0: Final[Color] = Color("#fffdd0")
_FAFAD2: Final[Color] = Color("#fafad2")
_FFFFE0: Final[Color] = Color("#ffffe0")
_F5F5DC: Final[Color] = Color("#f5f5dc")
_FFF8DC: Final[Color] = Color("#fff8dc")
_FBF6D9: Final[Color] = Color("#fbf6d9")
_F7E7CE: Final[Color] = Color("#f7e7ce")
_FAEBD7: Final[Color] = Color("#faebd7")
_FFEFD5: Final[Color] = Color("#ffefd5")
_FFEBCD: Final[Color] = Color("#ffebcd")
_FFE4C4: Final[Color] = Color("#ffe4c4")
_F5DEB3: Final[Color] = Color("#f5deb3")
_FFE4B5: Final[Color] = Color("#ffe4b5")
_FFE5B4: Final[Color] = Color("#ffe5b4")
_FED8B1: Final[Color] = Color("#fed8b1")
_FFDAB9: Final[Color] = Color("#ffdab9")
_FBD5AB: Final[Color] = Color("#fbd5ab")
_FFDEAD: Final[Color] = Color("#ffdead")
_FBE7A1: Final[Color] = Color("#fbe7a1")
_F3E3C3: Final[Color] = Color("#f3e3c3")
_F0E2B6: Final[Color] = Color("#f0e2b6")
_F1E5AC: Final[Color] = Color("#f1e5ac")
_F3E5AB: Final[Color] = Color("#f3e5ab")
_ECE5B6: Final[Color] = Color("#ece5b6")
_E8E4C9: Final[Color] = Color("#e8e4c9")
_EEE8AA: Final[Color] = Color("#eee8aa")
_F0E68C: Final[Color] = Color("#f0e68c")
_EDDA74: Final[Color] = Color("#edda74")
_EDE275: Final[Color] = Color("#ede275")
_FFE87C: Final[Color] = Color("#ffe87c")
_FFF380: Final[Color] = Color("#fff380")
_FAF884: Final[Color] = Color("#faf884")
_FFFF33: Final[Color] = Color("#ffff33")
_FFEF00: Final[Color] = Color("#ffef00")
_F5E216: Final[Color] = Color("#f5e216")
_FFDB58: Final[Color] = Color("#ffdb58")
_FFDF00: Final[Color] = Color("#ffdf00")
_F9DB24: Final[Color] = Color("#f9db24")
_FFD801: Final[Color] = Color("#ffd801")
_FDD017: Final[Color] = Color("#fdd017")
_FFCE44: Final[Color] = Color("#ffce44")
_EAC117: Final[Color] = Color("#eac117")
_F6BE00: Final[Color] = Color("#f6be00")
_F2BB66: Final[Color] = Color("#f2bb66")
_FBB917: Final[Color] = Color("#fbb917")
_FDBD01: Final[Color] = Color("#fdbd01")
_FBB117: Final[Color] = Color("#fbb117")
_FFAE42: Final[Color] = Color("#ffae42")
_FFA62F: Final[Color] = Color("#ffa62f")
_FFA600: Final[Color] = Color("#ffa600")
_EE9A4D: Final[Color] = Color("#ee9a4d")
_F4A460: Final[Color] = Color("#f4a460")
_E2A76F: Final[Color] = Color("#e2a76f")
_C19A6B: Final[Color] = Color("#c19a6b")
_E6BF83: Final[Color] = Color("#e6bf83")
_DEB887: Final[Color] = Color("#deb887")
_D2B48C: Final[Color] = Color("#d2b48c")
_C8AD7F: Final[Color] = Color("#c8ad7f")
_BCB88A: Final[Color] = Color("#bcB88A")
_C8B560: Final[Color] = Color("#c8b560")
_C9BE62: Final[Color] = Color("#c9be62")
_C9AE5D: Final[Color] = Color("#c9ae5d")
_BDB76B: Final[Color] = Color("#bdb76b")
_BAB86C: Final[Color] = Color("#bab86c")
_B5A642: Final[Color] = Color("#b5a642")
_C7A317: Final[Color] = Color("#c7a317")
_D4AF37: Final[Color] = Color("#d4af37")
_E9AB17: Final[Color] = Color("#e9ab17")
_E8A317: Final[Color] = Color("#e8a317")
_DAA520: Final[Color] = Color("#daa520")
_D4A017: Final[Color] = Color("#d4a017")
_C68E17: Final[Color] = Color("#c68e17")
_B8860B: Final[Color] = Color("#b8860b")
_C58917: Final[Color] = Color("#c58917")
_CD853F: Final[Color] = Color("#cd853f")
_CD7F32: Final[Color] = Color("#cd7f32")
_C88141: Final[Color] = Color("#c88141")
_B87333: Final[Color] = Color("#b87333")
_AA6C39: Final[Color] = Color("#aa6c39")
_A97142: Final[Color] = Color("#a97142")
_AB784E: Final[Color] = Color("#ab784e")
_966F33: Final[Color] = Color("#966f33")
_806517: Final[Color] = Color("#806517")
_665D1E: Final[Color] = Color("#665d1e")
_8E7618: Final[Color] = Color("#8e7618")
_8B8000: Final[Color] = Color("#8b8000")
_827839: Final[Color] = Color("#827839")
_8A865D: Final[Color] = Color("#8a865d")
_93917C: Final[Color] = Color("#93917c")
_9F8C76: Final[Color] = Color("#9f8c76")
_AF9B60: Final[Color] = Color("#af9b60")
_827B60: Final[Color] = Color("#827b60")
_786D5F: Final[Color] = Color("#786d5f")
_483C32: Final[Color] = Color("#483c32")
_493D26: Final[Color] = Color("#493d26")
_513B1C: Final[Color] = Color("#513b1c")
_3D3635: Final[Color] = Color("#3d3635")
_3B2F2F: Final[Color] = Color("#3b2f2f")
_49413F: Final[Color] = Color("#49413F")
_43302E: Final[Color] = Color("#43302E")
_622F22: Final[Color] = Color("#622f22")
_5C3317: Final[Color] = Color("#5c3317")
_654321: Final[Color] = Color("#654321")
_704214: Final[Color] = Color("#704214")
_804A00: Final[Color] = Color("#804a00")
_6F4E37: Final[Color] = Color("#6f4e37")
_835C3B: Final[Color] = Color("#835c3b")
_7F5217: Final[Color] = Color("#7f5217")
_7F462C: Final[Color] = Color("#7f462c")
_A0522D: Final[Color] = Color("#a0522d")
_8B4513: Final[Color] = Color("#8b4513")
_8A4117: Final[Color] = Color("#8a4117")
_7E3817: Final[Color] = Color("#7e3817")
_7E3517: Final[Color] = Color("#7e3517")
_954535: Final[Color] = Color("#954535")
_9E4638: Final[Color] = Color("#9e4638")
_C34A2C: Final[Color] = Color("#c34a2c")
_C04000: Final[Color] = Color("#c04000")
_EB5406: Final[Color] = Color("#eb5406")
_C35817: Final[Color] = Color("#c35817")
_B86500: Final[Color] = Color("#b86500")
_B5651D: Final[Color] = Color("#b5651d")
_B76734: Final[Color] = Color("#b76734")
_C36241: Final[Color] = Color("#c36241")
_CB6D51: Final[Color] = Color("#cb6d51")
_C47451: Final[Color] = Color("#c47451")
_D2691E: Final[Color] = Color("#d2691e")
_CC6600: Final[Color] = Color("#cc6600")
_E56717: Final[Color] = Color("#e56717")
_E66C2C: Final[Color] = Color("#e66c2c")
_FF6700: Final[Color] = Color("#ff6700")
_FF5F1F: Final[Color] = Color("#ff5f1f")
_F87217: Final[Color] = Color("#f87217")
_F88017: Final[Color] = Color("#f88017")
_FF8C00: Final[Color] = Color("#ff8c00")
_F87431: Final[Color] = Color("#f87431")
_FF7722: Final[Color] = Color("#ff7722")
_E67451: Final[Color] = Color("#e67451")
_FF8040: Final[Color] = Color("#ff8040")
_FF7F50: Final[Color] = Color("#ff7f50")
_F88158: Final[Color] = Color("#f88158")
_F9966B: Final[Color] = Color("#f9966b")
_FFA07A: Final[Color] = Color("#ffa07a")
_F89880: Final[Color] = Color("#f89880")
_E9967A: Final[Color] = Color("#e9967a")
_E78A61: Final[Color] = Color("#e78a61")
_DA8A67: Final[Color] = Color("#da8a67")
_FF8674: Final[Color] = Color("#ff8674")
_FA8072: Final[Color] = Color("#fa8072")
_F98B88: Final[Color] = Color("#f98b88")
_F08080: Final[Color] = Color("#f08080")
_F67280: Final[Color] = Color("#f67280")
_E77471: Final[Color] = Color("#e77471")
_F75D59: Final[Color] = Color("#f75d59")
_E55451: Final[Color] = Color("#e55451")
_CD5C5C: Final[Color] = Color("#cd5c5c")
_FF6347: Final[Color] = Color("#ff6347")
_E55B3C: Final[Color] = Color("#e55b3c")
_FF4500: Final[Color] = Color("#ff4500")
_FD1C03: Final[Color] = Color("#fd1c03")
_FF2400: Final[Color] = Color("#ff2400")
_F62217: Final[Color] = Color("#f62217")
_F62817: Final[Color] = Color("#f62817")
_E42217: Final[Color] = Color("#e42217")
_E41B17: Final[Color] = Color("#e41b17")
_DC381F: Final[Color] = Color("#dc381f")
_C24641: Final[Color] = Color("#c24641")
_C11B17: Final[Color] = Color("#c11b17")
_B22222: Final[Color] = Color("#b22222")
_B21807: Final[Color] = Color("#b21807")
_A70D2A: Final[Color] = Color("#a70d2a")
_9F000F: Final[Color] = Color("#9f000f")
_931314: Final[Color] = Color("#931314")
_990000: Final[Color] = Color("#990000")
_990012: Final[Color] = Color("#990012")
_8B0000: Final[Color] = Color("#8b0000")
_8F0B0B: Final[Color] = Color("#8f0b0b")
_8C001A: Final[Color] = Color("#8c001a")
_7E191B: Final[Color] = Color("#7e191b")
_800517: Final[Color] = Color("#800517")
_733635: Final[Color] = Color("#733635")
_660000: Final[Color] = Color("#660000")
_551606: Final[Color] = Color("#551606")
_560319: Final[Color] = Color("#560319")
_3F000F: Final[Color] = Color("#3f000f")
_3D0C02: Final[Color] = Color("#3d0c02")
_2F0909: Final[Color] = Color("#2f0909")
_2B1B17: Final[Color] = Color("#2b1b17")
_550A35: Final[Color] = Color("#550a35")
_810541: Final[Color] = Color("#810541")
_7D0541: Final[Color] = Color("#7d0541")
_7D0552: Final[Color] = Color("#7d0552")
_872657: Final[Color] = Color("#872657")
_7E354D: Final[Color] = Color("#7e354d")
_7F4E52: Final[Color] = Color("#7f4e52")
_7F525D: Final[Color] = Color("#7f525d")
_7F5A58: Final[Color] = Color("#7f5a58")
_997070: Final[Color] = Color("#997070")
_B1907F: Final[Color] = Color("#b1907f")
_B38481: Final[Color] = Color("#b38481")
_BC8F8F: Final[Color] = Color("#bc8f8f")
_C5908E: Final[Color] = Color("#c5908e")
_C48793: Final[Color] = Color("#c48793")
_CC7A8B: Final[Color] = Color("#cc7a8b")
_C48189: Final[Color] = Color("#c48189")
_C08081: Final[Color] = Color("#c08081")
_D58A94: Final[Color] = Color("#d58a94")
_E799A3: Final[Color] = Color("#e799a3")
_E8ADAA: Final[Color] = Color("#e8adaa")
_C9A9A6: Final[Color] = Color("#c9a9a6")
_E6C7C2: Final[Color] = Color("#e6c7c2")
_ECC5C0: Final[Color] = Color("#ecc5c0")
_FFCBA4: Final[Color] = Color("#ffcba4")
_F8B88B: Final[Color] = Color("#f8b88b")
_EDC9AF: Final[Color] = Color("#edc9af")
_FFDDCA: Final[Color] = Color("#ffddca")
_FDD7E4: Final[Color] = Color("#fdd7e4")
_F2D4D7: Final[Color] = Color("#f2d4d7")
_FFE6E8: Final[Color] = Color("#ffe6e8")
_FFE4E1: Final[Color] = Color("#ffe4e1")
_FFDFDD: Final[Color] = Color("#ffdfdd")
_FBCFCD: Final[Color] = Color("#fbcfcd")
_FFCCCB: Final[Color] = Color("#ffcccb")
_F6C6BD: Final[Color] = Color("#f6c6bd")
_FBBBB9: Final[Color] = Color("#fbbbb9")
_FFB6C1: Final[Color] = Color("#ffb6c1")
_FFB8BF: Final[Color] = Color("#ffb8bf")
_FFB2D0: Final[Color] = Color("#ffb2d0")
_FAAFBE: Final[Color] = Color("#faafbe")
_FAAFBA: Final[Color] = Color("#faafba")
_F9A7B0: Final[Color] = Color("#f9a7b0")
_FEA3AA: Final[Color] = Color("#fea3aa")
_E7A1B0: Final[Color] = Color("#e7a1b0")
_E38AAE: Final[Color] = Color("#e38aae")
_F778A1: Final[Color] = Color("#f778a1")
_E5788F: Final[Color] = Color("#e5788f")
_E56E94: Final[Color] = Color("#e56e94")
_DB7093: Final[Color] = Color("#db7093")
_D16587: Final[Color] = Color("#d16587")
_C25A7C: Final[Color] = Color("#c25a7c")
_C25283: Final[Color] = Color("#c25283")
_E75480: Final[Color] = Color("#e75480")
_F660AB: Final[Color] = Color("#f660ab")
_FF69B4: Final[Color] = Color("#ff69b4")
_FC6C85: Final[Color] = Color("#fc6c85")
_F6358A: Final[Color] = Color("#f6358a")
_F52887: Final[Color] = Color("#f52887")
_FF007F: Final[Color] = Color("#ff007f")
_FF1493: Final[Color] = Color("#ff1493")
_F535AA: Final[Color] = Color("#f535aa")
_FF33AA: Final[Color] = Color("#ff33aa")
_FD349C: Final[Color] = Color("#fd349c")
_E45E9D: Final[Color] = Color("#e45e9d")
_E759AC: Final[Color] = Color("#e759ac")
_E3319D: Final[Color] = Color("#e3319d")
_E4287C: Final[Color] = Color("#e4287c")
_FA2A55: Final[Color] = Color("#fa2a55")
_E30B5D: Final[Color] = Color("#e30b5d")
_DC143C: Final[Color] = Color("#dc143c")
_C32148: Final[Color] = Color("#c32148")
_C21E56: Final[Color] = Color("#c21e56")
_C12869: Final[Color] = Color("#c12869")
_C12267: Final[Color] = Color("#c12267")
_CA226B: Final[Color] = Color("#ca226b")
_CC338B: Final[Color] = Color("#cc338b")
_C71585: Final[Color] = Color("#c71585")
_C12283: Final[Color] = Color("#c12283")
_B3446C: Final[Color] = Color("#b3446c")
_B93B8F: Final[Color] = Color("#b93b8f")
_DA70D6: Final[Color] = Color("#da70d6")
_DF73D4: Final[Color] = Color("#df73d4")
_EE82EE: Final[Color] = Color("#ee82ee")
_FF77FF: Final[Color] = Color("#ff77ff")
_F433FF: Final[Color] = Color("#f433ff")
_E238EC: Final[Color] = Color("#e238ec")
_D462FF: Final[Color] = Color("#d462ff")
_C45AEC: Final[Color] = Color("#c45aec")
_BA55D3: Final[Color] = Color("#ba55d3")
_A74AC7: Final[Color] = Color("#a74ac7")
_B048B5: Final[Color] = Color("#b048b5")
_B666D2: Final[Color] = Color("#b666d2")
_D291BC: Final[Color] = Color("#d291bc")
_915F6D: Final[Color] = Color("#915f6d")
_7E587E: Final[Color] = Color("#7e587e")
_614051: Final[Color] = Color("#614051")
_583759: Final[Color] = Color("#583759")
_5E5A80: Final[Color] = Color("#5e5a80")
_4E5180: Final[Color] = Color("#4e5180")
_6A5ACD: Final[Color] = Color("#6a5acd")
_6960EC: Final[Color] = Color("#6960ec")
_5865F2: Final[Color] = Color("#5865f2")
_736AFF: Final[Color] = Color("#736aff")
_7B68EE: Final[Color] = Color("#7b68ee")
_7575CF: Final[Color] = Color("#7575cf")
_6667AB: Final[Color] = Color("#6667ab")
_6F2DA8: Final[Color] = Color("#6f2da8")
_6C2DC7: Final[Color] = Color("#6c2dc7")
_6A0DAD: Final[Color] = Color("#6a0dad")
_5453A6: Final[Color] = Color("#5453a6")
_483D8B: Final[Color] = Color("#483d8b")
_4E387E: Final[Color] = Color("#4e387e")
_571B7E: Final[Color] = Color("#571b7e")
_4B0150: Final[Color] = Color("#4b0150")
_36013F: Final[Color] = Color("#36013f")
_2E1A47: Final[Color] = Color("#2e1a47")
_4B0082: Final[Color] = Color("#4b0082")
_342D7E: Final[Color] = Color("#342d7e")
_663399: Final[Color] = Color("#663399")
_6A287E: Final[Color] = Color("#6a287e")
_8B008B: Final[Color] = Color("#8b008b")
_86608E: Final[Color] = Color("#86608e")
_9932CC: Final[Color] = Color("#9932cc")
_9400D3: Final[Color] = Color("#9400d3")
_8D38C9: Final[Color] = Color("#8d38c9")
_A23BEC: Final[Color] = Color("#a23bec")
_B041FF: Final[Color] = Color("#b041ff")
_842DCE: Final[Color] = Color("#842dce")
_8A2BE2: Final[Color] = Color("#8a2be2")
_7A5DC7: Final[Color] = Color("#7a5dc7")
_7F38EC: Final[Color] = Color("#7f38ec")
_9D00FF: Final[Color] = Color("#9d00ff")
_8E35EF: Final[Color] = Color("#8e35ef")
_893BFF: Final[Color] = Color("#893bff")
_9370DB: Final[Color] = Color("#9370db")
_8467D7: Final[Color] = Color("#8467d7")
_9172EC: Final[Color] = Color("#9172ec")
_9E7BFF: Final[Color] = Color("#9e7bff")
_CCCCFF: Final[Color] = Color("#ccccff")
_DCD0FF: Final[Color] = Color("#dcd0ff")
_967BB6: Final[Color] = Color("#967bb6")
_B09FCA: Final[Color] = Color("#b09fca")
_C8A2C8: Final[Color] = Color("#c8a2c8")
_E0B0FF: Final[Color] = Color("#e0b0ff")
_D891EF: Final[Color] = Color("#d891ef")
_C38EC7: Final[Color] = Color("#c38ec7")
_DDA0DD: Final[Color] = Color("#dda0dd")
_E6A9EC: Final[Color] = Color("#e6a9ec")
_F2A2E8: Final[Color] = Color("#f2a2e8")
_F9B7FF: Final[Color] = Color("#f9b7ff")
_C6AEC7: Final[Color] = Color("#c6aec7")
_D2B9D3: Final[Color] = Color("#d2b9d3")
_D8BFD8: Final[Color] = Color("#d8bfd8")
_DFD3E3: Final[Color] = Color("#dfd3e3")
_E9CFEC: Final[Color] = Color("#e9cfec")
_FCDFFF: Final[Color] = Color("#fcdfff")
_EBDDE2: Final[Color] = Color("#ebdde2")
_E1D9D1: Final[Color] = Color("#e1d9d1")
_E9E4D4: Final[Color] = Color("#e9e4d4")
_EFEBD8: Final[Color] = Color("#efebd8")
_FAF0DD: Final[Color] = Color("#faf0dd")
_F8F0E3: Final[Color] = Color("#f8f0e3")
_F8F6F0: Final[Color] = Color("#f8f6f0")
_F3E8EA: Final[Color] = Color("#f3e8ea")
_FFF0F5: Final[Color] = Color("#fff0f5")
_FDEEF4: Final[Color] = Color("#fdeef4")
_FFF9E3: Final[Color] = Color("#fff9e3")
_FEF0E3: Final[Color] = Color("#fef0e3")
_EAEEE9: Final[Color] = Color("#eaeee9")
_FAF0E6: Final[Color] = Color("#faf0e6")
_FFF5EE: Final[Color] = Color("#fff5ee")
_F9F6EE: Final[Color] = Color("#f9f6ee")
_FAF5EF: Final[Color] = Color("#faf5ef")
_FFFAF0: Final[Color] = Color("#fffaf0")
_FFFFF0: Final[Color] = Color("#fffff0")
_FFFFF4: Final[Color] = Color("#fffff4")
_FFFFF7: Final[Color] = Color("#fffff7")
_F5F5F5: Final[Color] = Color("#f5f5f5")
_FBFBF9: Final[Color] = Color("#fbfbf9")
_FFFAFA: Final[Color] = Color("#fffafa")
_FEFCFF: Final[Color] = Color("#fefcff")
_FFFEFA: Final[Color] = Color("#fffefa")
_F44336: Final[Color] = Color("#f44336")
_FFEBEE: Final[Color] = Color("#ffebee")
_FFCDD2: Final[Color] = Color("#ffcdd2")
_EF9A9A: Final[Color] = Color("#ef9a9a")
_E57373: Final[Color] = Color("#e57373")
_EF5350: Final[Color] = Color("#ef5350")
_E53935: Final[Color] = Color("#e53935")
_D32F2F: Final[Color] = Color("#d32f2f")
_C62828: Final[Color] = Color("#c62828")
_B71C1C: Final[Color] = Color("#b71c1c")
_FF8A80: Final[Color] = Color("#ff8a80")
_FF5252: Final[Color] = Color("#ff5252")
_FF1744: Final[Color] = Color("#ff1744")
_D50000: Final[Color] = Color("#d50000")
_FCE4EC: Final[Color] = Color("#fce4ec")
_F8BBD0: Final[Color] = Color("#f8bbd0")
_F48FB1: Final[Color] = Color("#f48fb1")
_F06292: Final[Color] = Color("#f06292")
_EC407A: Final[Color] = Color("#ec407a")
_E91E63: Final[Color] = Color("#e91e63")
_D81B60: Final[Color] = Color("#d81b60")
_C2185B: Final[Color] = Color("#c2185b")
_AD1457: Final[Color] = Color("#ad1457")
_880E4F: Final[Color] = Color("#880e4f")
_FF80AB: Final[Color] = Color("#ff80ab")
_FF4081: Final[Color] = Color("#ff4081")
_F50057: Final[Color] = Color("#f50057")
_C51162: Final[Color] = Color("#c51162")
_F3E5F5: Final[Color] = Color("#f3e5f5")
_E1BEE7: Final[Color] = Color("#e1bee7")
_CE93D8: Final[Color] = Color("#ce93d8")
_BA68C8: Final[Color] = Color("#ba68c8")
_AB47BC: Final[Color] = Color("#ab47bc")
_9C27B0: Final[Color] = Color("#9c27b0")
_8E24AA: Final[Color] = Color("#8e24aa")
_7B1FA2: Final[Color] = Color("#7b1fa2")
_6A1B9A: Final[Color] = Color("#6a1b9a")
_4A148C: Final[Color] = Color("#4a148c")
_EA80FC: Final[Color] = Color("#ea80fc")
_E040FB: Final[Color] = Color("#e040fb")
_D500F9: Final[Color] = Color("#d500f9")
_AA00FF: Final[Color] = Color("#aa00ff")
_EDE7F6: Final[Color] = Color("#ede7f6")
_D1C4E9: Final[Color] = Color("#d1c4e9")
_B39DDB: Final[Color] = Color("#b39ddb")
_9575CD: Final[Color] = Color("#9575cd")
_7E57C2: Final[Color] = Color("#7e57c2")
_673AB7: Final[Color] = Color("#673ab7")
_5E35B1: Final[Color] = Color("#5e35b1")
_512DA8: Final[Color] = Color("#512da8")
_4527A0: Final[Color] = Color("#4527a0")
_311B92: Final[Color] = Color("#311b92")
_B388FF: Final[Color] = Color("#b388ff")
_7C4DFF: Final[Color] = Color("#7c4dff")
_651FFF: Final[Color] = Color("#651fff")
_6200EA: Final[Color] = Color("#6200ea")
_E8EAF6: Final[Color] = Color("#e8eaf6")
_C5CAE9: Final[Color] = Color("#c5cae9")
_9FA8DA: Final[Color] = Color("#9fa8da")
_7986CB: Final[Color] = Color("#7986cb")
_5C6BC0: Final[Color] = Color("#5c6bc0")
_3F51B5: Final[Color] = Color("#3f51b5")
_3949AB: Final[Color] = Color("#3949ab")
_303F9F: Final[Color] = Color("#303f9f")
_283593: Final[Color] = Color("#283593")
_1A237E: Final[Color] = Color("#1a237e")
_8C9EFF: Final[Color] = Color("#8c9eff")
_536DFE: Final[Color] = Color("#536dfe")
_3D5AFE: Final[Color] = Color("#3d5afe")
_304FFE: Final[Color] = Color("#304ffe")
_E3F2FD: Final[Color] = Color("#e3f2fd")
_BBDEFB: Final[Color] = Color("#bbdefb")
_90CAF9: Final[Color] = Color("#90caf9")
_64B5F6: Final[Color] = Color("#64b5f6")
_42A5F5: Final[Color] = Color("#42a5f5")
_2196F3: Final[Color] = Color("#2196f3")
_1E88E5: Final[Color] = Color("#1e88e5")
_1976D2: Final[Color] = Color("#1976d2")
_1565C0: Final[Color] = Color("#1565c0")
_0D47A1: Final[Color] = Color("#0d47a1")
_82B1FF: Final[Color] = Color("#82b1ff")
_448AFF: Final[Color] = Color("#448aff")
_2979FF: Final[Color] = Color("#2979ff")
_2962FF: Final[Color] = Color("#2962ff")
_E1F5FE: Final[Color] = Color("#E1F5FE")
_B3E5FC: Final[Color] = Color("#B3E5FC")
_81D4FA: Final[Color] = Color("#81D4FA")
_4FC3F7: Final[Color] = Color("#4FC3F7")
_29B6F6: Final[Color] = Color("#29B6F6")
_03A9F4: Final[Color] = Color("#03A9F4")
_039BE5: Final[Color] = Color("#039BE5")
_0288D1: Final[Color] = Color("#0288D1")
_0277BD: Final[Color] = Color("#0277BD")
_01579B: Final[Color] = Color("#01579B")
_80D8FF: Final[Color] = Color("#80D8FF")
_40C4FF: Final[Color] = Color("#40C4FF")
_00B0FF: Final[Color] = Color("#00B0FF")
_0091EA: Final[Color] = Color("#0091EA")
_E0F7FA: Final[Color] = Color("#E0F7FA")
_B2EBF2: Final[Color] = Color("#B2EBF2")
_80DEEA: Final[Color] = Color("#80DEEA")
_4DD0E1: Final[Color] = Color("#4DD0E1")
_26C6DA: Final[Color] = Color("#26C6DA")
_00BCD4: Final[Color] = Color("#00BCD4")
_00ACC1: Final[Color] = Color("#00ACC1")
_0097A7: Final[Color] = Color("#0097A7")
_00838F: Final[Color] = Color("#00838F")
_006064: Final[Color] = Color("#006064")
_84FFFF: Final[Color] = Color("#84FFFF")
_18FFFF: Final[Color] = Color("#18FFFF")
_00E5FF: Final[Color] = Color("#00E5FF")
_00B8D4: Final[Color] = Color("#00B8D4")
_E0F2F1: Final[Color] = Color("#E0F2F1")
_B2DFDB: Final[Color] = Color("#B2DFDB")
_80CBC4: Final[Color] = Color("#80CBC4")
_4DB6AC: Final[Color] = Color("#4DB6AC")
_26A69A: Final[Color] = Color("#26A69A")
_009688: Final[Color] = Color("#009688")
_00897B: Final[Color] = Color("#00897B")
_00796B: Final[Color] = Color("#00796B")
_00695C: Final[Color] = Color("#00695C")
_004D40: Final[Color] = Color("#004D40")
_A7FFEB: Final[Color] = Color("#A7FFEB")
_64FFDA: Final[Color] = Color("#64FFDA")
_1DE9B6: Final[Color] = Color("#1DE9B6")
_00BFA5: Final[Color] = Color("#00BFA5")
_E8F5E9: Final[Color] = Color("#E8F5E9")
_C8E6C9: Final[Color] = Color("#C8E6C9")
_A5D6A7: Final[Color] = Color("#A5D6A7")
_81C784: Final[Color] = Color("#81C784")
_66BB6A: Final[Color] = Color("#66BB6A")
_4CAF50: Final[Color] = Color("#4CAF50")
_43A047: Final[Color] = Color("#43A047")
_388E3C: Final[Color] = Color("#388E3C")
_2E7D32: Final[Color] = Color("#2E7D32")
_1B5E20: Final[Color] = Color("#1B5E20")
_B9F6CA: Final[Color] = Color("#B9F6CA")
_69F0AE: Final[Color] = Color("#69F0AE")
_00E676: Final[Color] = Color("#00E676")
_00C853: Final[Color] = Color("#00C853")
_F1F8E9: Final[Color] = Color("#F1F8E9")
_DCEDC8: Final[Color] = Color("#DCEDC8")
_C5E1A5: Final[Color] = Color("#C5E1A5")
_AED581: Final[Color] = Color("#AED581")
_9CCC65: Final[Color] = Color("#9CCC65")
_8BC34A: Final[Color] = Color("#8BC34A")
_7CB342: Final[Color] = Color("#7CB342")
_689F38: Final[Color] = Color("#689F38")
_558B2F: Final[Color] = Color("#558B2F")
_33691E: Final[Color] = Color("#33691E")
_CCFF90: Final[Color] = Color("#CCFF90")
_B2FF59: Final[Color] = Color("#B2FF59")
_76FF03: Final[Color] = Color("#76FF03")
_64DD17: Final[Color] = Color("#64DD17")
_F9FBE7: Final[Color] = Color("#F9FBE7")
_F0F4C3: Final[Color] = Color("#F0F4C3")
_E6EE9C: Final[Color] = Color("#E6EE9C")
_DCE775: Final[Color] = Color("#DCE775")
_D4E157: Final[Color] = Color("#D4E157")
_CDDC39: Final[Color] = Color("#CDDC39")
_C0CA33: Final[Color] = Color("#C0CA33")
_AFB42B: Final[Color] = Color("#AFB42B")
_9E9D24: Final[Color] = Color("#9E9D24")
_827717: Final[Color] = Color("#827717")
_F4FF81: Final[Color] = Color("#F4FF81")
_EEFF41: Final[Color] = Color("#EEFF41")
_C6FF00: Final[Color] = Color("#C6FF00")
_AEEA00: Final[Color] = Color("#AEEA00")
_FFFDE7: Final[Color] = Color("#FFFDE7")
_FFF9C4: Final[Color] = Color("#FFF9C4")
_FFF59D: Final[Color] = Color("#FFF59D")
_FFF176: Final[Color] = Color("#FFF176")
_FFEE58: Final[Color] = Color("#FFEE58")
_FFEB3B: Final[Color] = Color("#FFEB3B")
_FDD835: Final[Color] = Color("#FDD835")
_FBC02D: Final[Color] = Color("#FBC02D")
_F9A825: Final[Color] = Color("#F9A825")
_F57F17: Final[Color] = Color("#F57F17")
_FFFF8D: Final[Color] = Color("#FFFF8D")
_FFEA00: Final[Color] = Color("#FFEA00")
_FFD600: Final[Color] = Color("#FFD600")
_FFF8E1: Final[Color] = Color("#FFF8E1")
_FFECB3: Final[Color] = Color("#FFECB3")
_FFE082: Final[Color] = Color("#FFE082")
_FFD54F: Final[Color] = Color("#FFD54F")
_FFCA28: Final[Color] = Color("#FFCA28")
_FFC107: Final[Color] = Color("#FFC107")
_FFB300: Final[Color] = Color("#FFB300")
_FFA000: Final[Color] = Color("#FFA000")
_FF8F00: Final[Color] = Color("#FF8F00")
_FF6F00: Final[Color] = Color("#FF6F00")
_FFE57F: Final[Color] = Color("#FFE57F")
_FFD740: Final[Color] = Color("#FFD740")
_FFC400: Final[Color] = Color("#FFC400")
_FFAB00: Final[Color] = Color("#FFAB00")
_FFF3E0: Final[Color] = Color("#FFF3E0")
_FFE0B2: Final[Color] = Color("#FFE0B2")
_FFCC80: Final[Color] = Color("#FFCC80")
_FFB74D: Final[Color] = Color("#FFB74D")
_FFA726: Final[Color] = Color("#FFA726")
_FF9800: Final[Color] = Color("#FF9800")
_FB8C00: Final[Color] = Color("#FB8C00")
_F57C00: Final[Color] = Color("#F57C00")
_EF6C00: Final[Color] = Color("#EF6C00")
_E65100: Final[Color] = Color("#E65100")
_FFD180: Final[Color] = Color("#FFD180")
_FFAB40: Final[Color] = Color("#FFAB40")
_FF9100: Final[Color] = Color("#FF9100")
_FF6D00: Final[Color] = Color("#FF6D00")
_FBE9E7: Final[Color] = Color("#FBE9E7")
_FFCCBC: Final[Color] = Color("#FFCCBC")
_FFAB91: Final[Color] = Color("#FFAB91")
_FF8A65: Final[Color] = Color("#FF8A65")
_FF7043: Final[Color] = Color("#FF7043")
_FF5722: Final[Color] = Color("#FF5722")
_F4511E: Final[Color] = Color("#F4511E")
_E64A19: Final[Color] = Color("#E64A19")
_D84315: Final[Color] = Color("#D84315")
_BF360C: Final[Color] = Color("#BF360C")
_FF9E80: Final[Color] = Color("#FF9E80")
_FF6E40: Final[Color] = Color("#FF6E40")
_FF3D00: Final[Color] = Color("#FF3D00")
_DD2C00: Final[Color] = Color("#DD2C00")
_EFEBE9: Final[Color] = Color("#EFEBE9")
_D7CCC8: Final[Color] = Color("#D7CCC8")
_BCAAA4: Final[Color] = Color("#BCAAA4")
_A1887F: Final[Color] = Color("#A1887F")
_8D6E63: Final[Color] = Color("#8D6E63")
_795548: Final[Color] = Color("#795548")
_6D4C41: Final[Color] = Color("#6D4C41")
_5D4037: Final[Color] = Color("#5D4037")
_4E342E: Final[Color] = Color("#4E342E")
_3E2723: Final[Color] = Color("#3E2723")
_FAFAFA: Final[Color] = Color("#FAFAFA")
_E0E0E0: Final[Color] = Color("#E0E0E0")
_BDBDBD: Final[Color] = Color("#BDBDBD")
_9E9E9E: Final[Color] = Color("#9E9E9E")
_616161: Final[Color] = Color("#616161")
_424242: Final[Color] = Color("#424242")
_212121: Final[Color] = Color("#212121")
_ECEFF1: Final[Color] = Color("#ECEFF1")
_CFD8DC: Final[Color] = Color("#CFD8DC")
_B0BEC5: Final[Color] = Color("#B0BEC5")
_90A4AE: Final[Color] = Color("#90A4AE")
_78909C: Final[Color] = Color("#78909C")
_607D8B: Final[Color] = Color("#607D8B")
_546E7A: Final[Color] = Color("#546E7A")
_455A64: Final[Color] = Color("#455A64")
_37474F: Final[Color] = Color("#37474F")
_263238: Final[Color] = Color("#263238")


class Colors(GetColorsMenmbersMixIn):
    """
    Color constants class.

    References
    ----------
    - Computer Hope, HTML color codes and names
        - https://www.computerhope.com/htmcolor.htm
    - Colors class
        - https://simon-ritchie.github.io/apysc/en/colors.html
    """

    BLACK_000000: Final[Color] = _000000
    BLACK_111111: Final[Color] = _111111
    BLACK_222222: Final[Color] = _222222
    GRAY_333333: Final[Color] = _333333
    GRAY_444444: Final[Color] = _444444
    GRAY_555555: Final[Color] = _555555
    GRAY_666666: Final[Color] = _666666
    GRAY_777777: Final[Color] = _777777
    GRAY_888888: Final[Color] = _888888
    GRAY_999999: Final[Color] = _999999
    GRAY_AAAAAA: Final[Color] = _AAAAAA
    GRAY_BBBBBB: Final[Color] = _BBBBBB
    GRAY_CCCCCC: Final[Color] = _CCCCCC
    GRAY_DDDDDD: Final[Color] = _DDDDDD
    SILVER_C0C0C0: Final[Color] = _C0C0C0
    WHITE_DDDDDD: Final[Color] = _DDDDDD
    WHITE_EEEEEE: Final[Color] = _EEEEEE
    WHITE_FFFFFF: Final[Color] = _FFFFFF
    NIGHT_0C090A: Final[Color] = _0C090A
    CHARCOAL_34282C: Final[Color] = _34282C
    OIL_3B3131: Final[Color] = _3B3131
    DARK_GRAY_3A3B3C: Final[Color] = _3A3B3C
    LIGHT_BLACK_454545: Final[Color] = _454545
    BLACK_CAT_413839: Final[Color] = _413839
    IRIDIUM_3D3C3A: Final[Color] = _3D3C3A
    BLACK_EEL_463E3F: Final[Color] = _463E3F
    BLACK_COW_4C4646: Final[Color] = _4C4646
    GRAY_WOLF_504A4B: Final[Color] = _504A4B
    VAMPIRE_GRAY_565051: Final[Color] = _565051
    IRON_GRAY_52595D: Final[Color] = _52595D
    GRAY_DOLPHIN_5C5858: Final[Color] = _5C5858
    CARBON_GRAY_625D5D: Final[Color] = _625D5D
    ASH_GRAY_666362: Final[Color] = _666362
    DIM_GRAY_696969: Final[Color] = _696969
    NARDO_GRAY_686A6C: Final[Color] = _686A6C
    CLOUDY_GRAY_6D6968: Final[Color] = _6D6968
    SMOKEY_GRAY_726E6D: Final[Color] = _726E6D
    ALIEN_GRAY_736F6E: Final[Color] = _736F6E
    SONIC_SILVER_757575: Final[Color] = _757575
    PLATINUM_GRAY_797979: Final[Color] = _797979
    GRAY_808080: Final[Color] = _808080
    GRANITE_837E7C: Final[Color] = _837E7C
    BATTLESHIP_GRAY_848482: Final[Color] = _848482
    GUNMETAL_GRAY_8D918D: Final[Color] = _8D918D
    DARK_GRAY_A9A9A9: Final[Color] = _A9A9A9
    GRAY_CLOUD_B6B6B4: Final[Color] = _B6B6B4
    PALE_SILVER_C9C0BB: Final[Color] = _C9C0BB
    GRAY_GOOSE_D1D0CE: Final[Color] = _D1D0CE
    PLATINUM_SILVER_CECECE: Final[Color] = _CECECE
    LIGHT_GRAY_D3D3D3: Final[Color] = _D3D3D3
    SILVER_WHITE_DADBDD: Final[Color] = _DADBDD
    GAINSBORO_DCDCDC: Final[Color] = _DCDCDC
    PLATINUM_E5E4E2: Final[Color] = _E5E4E2
    METALLIC_SILVER_BCC6CC: Final[Color] = _BCC6CC
    BLUE_GRAY_98AFC7: Final[Color] = _98AFC7
    ROMAN_SILVER_838996: Final[Color] = _838996
    LIGHT_SLATE_GRAY_778899: Final[Color] = _778899
    RAT_GRAY_708090: Final[Color] = _708090
    SLATE_GRANITE_GRAY_657383: Final[Color] = _657383
    JET_GRAY_616D7E: Final[Color] = _616D7E
    MIST_BLUE_646D7E: Final[Color] = _646D7E
    MARBLE_BLUE_566D7E: Final[Color] = _566D7E
    SLATE_BLUE_GREY_737CA1: Final[Color] = _737CA1
    LIGHT_PURPLE_BLUE_728FCE: Final[Color] = _728FCE
    AZURE_BLUE_4863A0: Final[Color] = _4863A0
    ESTORIL_BLUE_2F539B: Final[Color] = _2F539B
    BLUE_JAY_2B547E: Final[Color] = _2B547E
    CHARCOAL_BLUE_36454F: Final[Color] = _36454F
    DARK_BLUE_GREY_29465B: Final[Color] = _29465B
    DARK_SLATE_2B3856: Final[Color] = _2B3856
    DEEP_SEA_BLUE_123456: Final[Color] = _123456
    NIGHT_BLUE_151B54: Final[Color] = _151B54
    MIDNIGHT_BLUE_191970: Final[Color] = _191970
    NAVY_000080: Final[Color] = _000080
    DENIM_DARK_BLUE_151B8D: Final[Color] = _151B8D
    DARK_BLUE_00008B: Final[Color] = _00008B
    LAPIS_BLUE_15317E: Final[Color] = _15317E
    NEW_MIDNIGHT_BLUE_0000A0: Final[Color] = _0000A0
    EARTH_BLUE_0000A5: Final[Color] = _0000A5
    COBALT_BLUE_0020C2: Final[Color] = _0020C2
    MEDIUM_BLUE_0000CD: Final[Color] = _0000CD
    BLUEBERRY_BLUE_0041C2: Final[Color] = _0041C2
    CANARY_BLUE_2916F5: Final[Color] = _2916F5
    BLUE_0000FF: Final[Color] = _0000FF
    SAMCO_BLUE_0002FF: Final[Color] = _0002FF
    BRIGHT_BLUE_0909FF: Final[Color] = _0909FF
    BLUE_ORCHID_1F45FC: Final[Color] = _1F45FC
    SAPPHIRE_BLUE_2554C7: Final[Color] = _2554C7
    BLUE_EYES_1569C7: Final[Color] = _1569C7
    BRIGHT_NAVY_BLUE_1974D2: Final[Color] = _1974D2
    BALLOON_BLUE_2B60DE: Final[Color] = _2B60DE
    ROYAL_BLUE_4169E1: Final[Color] = _4169E1
    OCEAN_BLUE_2B65EC: Final[Color] = _2B65EC
    BLUE_RIBBON_306EFF: Final[Color] = _306EFF
    BLUE_DRESS_157DEC: Final[Color] = _157DEC
    NEON_BLUE_1589FF: Final[Color] = _1589FF
    DODGER_BLUE_1E90FF: Final[Color] = _1E90FF
    GLACIAL_BLUE_ICE_368BC1: Final[Color] = _368BC1
    STEEL_BLUE_4682B4: Final[Color] = _4682B4
    SILK_BLUE_488AC7: Final[Color] = _488AC7
    BLUE_IVY_3090C7: Final[Color] = _3090C7
    BLUE_KOI_659EC7: Final[Color] = _659EC7
    COLUMBIA_BLUE_87AFC7: Final[Color] = _87AFC7
    BABY_BLUE_95B9C7: Final[Color] = _95B9C7
    CORNFLOWER_BLUE_6495ED: Final[Color] = _6495ED
    SKY_BLUE_DRESS_6698FF: Final[Color] = _6698FF
    ICEBERG_56A5EC: Final[Color] = _56A5EC
    BUTTERFLY_BLUE_38ACEC: Final[Color] = _38ACEC
    DEEPSKYBLUE_00BFFF: Final[Color] = _00BFFF
    MIDDAY_BLUE_3BB9FF: Final[Color] = _3BB9FF
    CRYSTAL_BLUE_5CB3FF: Final[Color] = _5CB3FF
    DENIM_BLUE_79BAEC: Final[Color] = _79BAEC
    DAY_SKY_BLUE_82CAFF: Final[Color] = _82CAFF
    LIGHT_SKY_BLUE_87CEFA: Final[Color] = _87CEFA
    SKY_BLUE_87CEEB: Final[Color] = _87CEEB
    JEANS_BLUE_A0CFEC: Final[Color] = _A0CFEC
    BLUE_ANGEL_B7CEEC: Final[Color] = _B7CEEC
    PASTEL_BLUE_B4CFEC: Final[Color] = _B4CFEC
    LIGHT_DAY_BLUE_ADDFFF: Final[Color] = _ADDFFF
    SEA_BLUE_C2DFFF: Final[Color] = _C2DFFF
    HEAVENLY_BLUE_C6DEFF: Final[Color] = _C6DEFF
    ROBIN_EGG_BLUE_BDEDFF: Final[Color] = _BDEDFF
    POWDER_BLUE_B0E0E6: Final[Color] = _B0E0E6
    CORAL_BLUE_AFDCEC: Final[Color] = _AFDCEC
    LIGHT_BLUE_ADD8E6: Final[Color] = _ADD8E6
    LIGHT_STEEL_BLUE_B0CFDE: Final[Color] = _B0CFDE
    GULF_BLUE_C9DFEC: Final[Color] = _C9DFEC
    PASTEL_LIGHT_BLUE_D5D6EA: Final[Color] = _D5D6EA
    LAVENDER_BLUE_E3E4FA: Final[Color] = _E3E4FA
    WHITE_BLUE_DBE9FA: Final[Color] = _DBE9FA
    LAVENDER_E6E6FA: Final[Color] = _E6E6FA
    WATER_EBF4FA: Final[Color] = _EBF4FA
    ALICE_BLUE_F0F8FF: Final[Color] = _F0F8FF
    GHOST_WHITE_F8F8FF: Final[Color] = _F8F8FF
    AZURE_F0FFFF: Final[Color] = _F0FFFF
    LIGHT_CYAN_E0FFFF: Final[Color] = _E0FFFF
    LIGHT_SLATE_CCFFFF: Final[Color] = _CCFFFF
    ELECTRIC_BLUE_9AFEFF: Final[Color] = _9AFEFF
    TRON_BLUE_7DFDFE: Final[Color] = _7DFDFE
    BLUE_ZIRCON_57FEFF: Final[Color] = _57FEFF
    CYAN_00AAFF: Final[Color] = _00AAFF
    CYAN_00FFFF: Final[Color] = _00FFFF
    BRIGHT_CYAN_0AFFFF: Final[Color] = _0AFFFF
    CELESTE_50EBEC: Final[Color] = _50EBEC
    BLUE_DIAMOND_4EE2EC: Final[Color] = _4EE2EC
    BRIGHT_TURQUOISE_16E2F5: Final[Color] = _16E2F5
    BLUE_LAGOON_8EEBEC: Final[Color] = _8EEBEC
    PALE_TURQUOISE_AFEEEE: Final[Color] = _AFEEEE
    PALE_BLUE_LILY_CFECEC: Final[Color] = _CFECEC
    LIGHT_TEAL_B3D9D9: Final[Color] = _B3D9D9
    BLUE_HOSTA_77BFC7: Final[Color] = _77BFC7
    CYAN_OPAQUE_92C7C7: Final[Color] = _92C7C7
    NORTHERN_LIGHTS_BLUE_78C7C7: Final[Color] = _78C7C7
    BLUE_GREEN_7BCCB5: Final[Color] = _7BCCB5
    MEDIUM_AQUA_MARINE_66CDAA: Final[Color] = _66CDAA
    MAGIC_MINT_AAF0D1: Final[Color] = _AAF0D1
    LIGHT_AQUAMARINE_93FFE8: Final[Color] = _93FFE8
    AQUAMARINE_7FFFD4: Final[Color] = _7FFFD4
    BRIGHT_TEAL_01F9C6: Final[Color] = _01F9C6
    TURQUOISE_40E0D0: Final[Color] = _40E0D0
    MEDIUM_TURQUOISE_48D1CC: Final[Color] = _48D1CC
    DEEP_TURQUOISE_48CCCD: Final[Color] = _48CCCD
    JELLYFISH_46C7C7: Final[Color] = _46C7C7
    BLUE_TURQUOISE_43C6DB: Final[Color] = _43C6DB
    DARK_TURQUOISE_00CED1: Final[Color] = _00CED1
    MACAW_BLUE_GREEN_43BFC7: Final[Color] = _43BFC7
    LIGHT_SEA_GREEN_20B2AA: Final[Color] = _20B2AA
    SEAFOAM_GREEN_3EA99F: Final[Color] = _3EA99F
    CADET_BLUE_5F9EA0: Final[Color] = _5F9EA0
    DEEP_SEA_3B9C9C: Final[Color] = _3B9C9C
    DARK_CYAN_008B8B: Final[Color] = _008B8B
    TEAL_GREEN_00827F: Final[Color] = _00827F
    TEAL_008080: Final[Color] = _008080
    TEAL_BLUE_007C80: Final[Color] = _007C80
    MEDIUM_TEAL_045F5F: Final[Color] = _045F5F
    DARK_TEAL_045D5D: Final[Color] = _045D5D
    DEEP_TEAL_033E3E: Final[Color] = _033E3E
    DARK_SLATE_GRAY_25383C: Final[Color] = _25383C
    GUNMETAL_2C3539: Final[Color] = _2C3539
    BLUE_MOSS_GREEN_3C565B: Final[Color] = _3C565B
    BEETLE_GREEN_4C787E: Final[Color] = _4C787E
    GRAYISH_TURQUOISE_5E7D7E: Final[Color] = _5E7D7E
    GREENISH_BLUE_307D7E: Final[Color] = _307D7E
    AQUAMARINE_STONE_348781: Final[Color] = _348781
    SEA_TURTLE_GREEN_438D80: Final[Color] = _438D80
    DULL_SEA_GREEN_4E8975: Final[Color] = _4E8975
    DARK_GREEN_BLUE_1F6357: Final[Color] = _1F6357
    DEEP_SEA_GREEN_306754: Final[Color] = _306754
    BOTTLE_GREEN_006A4E: Final[Color] = _006A4E
    SEA_GREEN_2E8B57: Final[Color] = _2E8B57
    ELF_GREEN_1B8A6B: Final[Color] = _1B8A6B
    DARK_MINT_31906E: Final[Color] = _31906E
    JADE_00A36C: Final[Color] = _00A36C
    EARTH_GREEN_34A56F: Final[Color] = _34A56F
    CHROME_GREEN_1AA260: Final[Color] = _1AA260
    EMERALD_50C878: Final[Color] = _50C878
    MINT_3EB489: Final[Color] = _3EB489
    MEDIUM_SEA_GREEN_3CB371: Final[Color] = _3CB371
    METALLIC_GREEN_7C9D8E: Final[Color] = _7C9D8E
    CAMOUFLAGE_GREEN_78866B: Final[Color] = _78866B
    SAGE_GREEN_848B79: Final[Color] = _848B79
    HAZEL_GREEN_617C58: Final[Color] = _617C58
    VENOM_GREEN_728C00: Final[Color] = _728C00
    OLIVE_DRAB_6B8E23: Final[Color] = _6B8E23
    OLIVE_808000: Final[Color] = _808000
    DARK_OLIVE_GREEN_556B2F: Final[Color] = _556B2F
    MILITARY_GREEN_4E5B31: Final[Color] = _4E5B31
    GREEN_LEAVES_3A5F0B: Final[Color] = _3A5F0B
    ARMY_GREEN_4B5320: Final[Color] = _4B5320
    FERN_GREEN_667C26: Final[Color] = _667C26
    FALL_FOREST_GREEN_4E9258: Final[Color] = _4E9258
    IRISH_GREEN_08A04B: Final[Color] = _08A04B
    PINE_GREEN_387C44: Final[Color] = _387C44
    MEDIUM_FOREST_GREEN_347235: Final[Color] = _347235
    JUNGLE_GREEN_347C2C: Final[Color] = _347C2C
    CACTUS_GREEN_227442: Final[Color] = _227442
    FOREST_GREEN_228B22: Final[Color] = _228B22
    GREEN_008000: Final[Color] = _008000
    DARK_GREEN_006400: Final[Color] = _006400
    DEEP_GREEN_056608: Final[Color] = _056608
    DEEP_EMERALD_GREEN_046307: Final[Color] = _046307
    HUNTER_GREEN_355E3B: Final[Color] = _355E3B
    DARK_FOREST_GREEN_254117: Final[Color] = _254117
    LOTUS_GREEN_004225: Final[Color] = _004225
    SEAWEED_GREEN_437C17: Final[Color] = _437C17
    SHAMROCK_GREEN_347C17: Final[Color] = _347C17
    GREEN_ONION_6AA121: Final[Color] = _6AA121
    MOSS_GREEN_8A9A5B: Final[Color] = _8A9A5B
    GRASS_GREEN_3F9B0B: Final[Color] = _3F9B0B
    GREEN_PEPPER_4AA02C: Final[Color] = _4AA02C
    DARK_LIME_GREEN_41A317: Final[Color] = _41A317
    PARROT_GREEN_12AD2B: Final[Color] = _12AD2B
    CLOVER_GREEN_3EA055: Final[Color] = _3EA055
    DINOSAUR_GREEN_73A16C: Final[Color] = _73A16C
    GREEN_SNAKE_6CBB3C: Final[Color] = _6CBB3C
    ALIEN_GREEN_6CC417: Final[Color] = _6CC417
    GREEN_APPLE_4CC417: Final[Color] = _4CC417
    LIME_GREEN_32CD32: Final[Color] = _32CD32
    PEA_GREEN_52D017: Final[Color] = _52D017
    KELLY_GREEN_4CC552: Final[Color] = _4CC552
    ZOMBIE_GREEN_54C571: Final[Color] = _54C571
    GREEN_PEAS_89C35C: Final[Color] = _89C35C
    DOLLAR_BILL_GREEN_85BB65: Final[Color] = _85BB65
    FROG_GREEN_99C68E: Final[Color] = _99C68E
    TURQUOISE_GREEN_A0D6B4: Final[Color] = _A0D6B4
    DARK_SEA_GREEN_8FBC8F: Final[Color] = _8FBC8F
    BASIL_GREEN_829F82: Final[Color] = _829F82
    GRAY_GREEN_A2AD9C: Final[Color] = _A2AD9C
    IGUANA_GREEN_9CB071: Final[Color] = _9CB071
    CITRON_GREEN_8FB31D: Final[Color] = _8FB31D
    ACID_GREEN_B0BF1A: Final[Color] = _B0BF1A
    AVOCADO_GREEN_B2C248: Final[Color] = _B2C248
    PISTACHIO_GREEN_9DC209: Final[Color] = _9DC209
    SALAD_GREEN_A1C935: Final[Color] = _A1C935
    YELLOW_GREEN_9ACD32: Final[Color] = _9ACD32
    PASTEL_GREEN_77DD77: Final[Color] = _77DD77
    HUMMINGBIRD_GREEN_7FE817: Final[Color] = _7FE817
    NEBULA_GREEN_59E817: Final[Color] = _59E817
    STOPLIGHT_GO_GREEN_57E964: Final[Color] = _57E964
    NEON_GREEN_16F529: Final[Color] = _16F529
    JADE_GREEN_5EFB6E: Final[Color] = _5EFB6E
    LIME_MINT_GREEN_36F57F: Final[Color] = _36F57F
    SPRING_GREEN_00FF7F: Final[Color] = _00FF7F
    MEDIUM_SPRING_GREEN_00FA9A: Final[Color] = _00FA9A
    EMERALD_GREEN_5FFB17: Final[Color] = _5FFB17
    LIME_00FF00: Final[Color] = _00FF00
    GREEN_00FF00: Final[Color] = _00FF00
    LAWN_GREEN_7CFC00: Final[Color] = _7CFC00
    BRIGHT_GREEN_66FF00: Final[Color] = _66FF00
    CHARTREUSE_7FFF00: Final[Color] = _7FFF00
    YELLOW_LAWN_GREEN_87F717: Final[Color] = _87F717
    ALOE_VERA_GREEN_98F516: Final[Color] = _98F516
    DULL_GREEN_YELLOW_B1FB17: Final[Color] = _B1FB17
    LEMON_GREEN_ADF802: Final[Color] = _ADF802
    GREEN_YELLOW_ADFF2F: Final[Color] = _ADFF2F
    CHAMELEON_GREEN_BDF516: Final[Color] = _BDF516
    NEON_YELLOW_GREEN_DAEE01: Final[Color] = _DAEE01
    YELLOW_GREEN_GROSBEAK_E2F516: Final[Color] = _E2F516
    TEA_GREEN_CCFB5D: Final[Color] = _CCFB5D
    SLIME_GREEN_BCE954: Final[Color] = _BCE954
    ALGAE_GREEN_64E986: Final[Color] = _64E986
    LIGHT_GREEN_90EE90: Final[Color] = _90EE90
    DRAGON_GREEN_6AFB92: Final[Color] = _6AFB92
    PALE_GREEN_98FB98: Final[Color] = _98FB98
    MINT_GREEN_98FF98: Final[Color] = _98FF98
    GREEN_THUMB_B5EAAA: Final[Color] = _B5EAAA
    ORGANIC_BROWN_E3F9A6: Final[Color] = _E3F9A6
    LIGHT_JADE_GREEN_C3FDB8: Final[Color] = _C3FDB8
    LIGHT_MINT_GREEN_C2E5D3: Final[Color] = _C2E5D3
    LIGHT_ROSE_GREEN_DBF9DB: Final[Color] = _DBF9DB
    CHROME_WHITE_E8F1D4: Final[Color] = _E8F1D4
    HONEY_DEW_F0FFF0: Final[Color] = _F0FFF0
    MINT_CREAM_F5FFFA: Final[Color] = _F5FFFA
    LEMON_CHIFFON_FFFACD: Final[Color] = _FFFACD
    PARCHMENT_FFFFC2: Final[Color] = _FFFFC2
    CREAM_FFFFCC: Final[Color] = _FFFFCC
    CREAM_WHITE_FFFDD0: Final[Color] = _FFFDD0
    LIGHT_GOLDEN_ROD_YELLOW_FAFAD2: Final[Color] = _FAFAD2
    LIGHT_YELLOW_FFFFE0: Final[Color] = _FFFFE0
    BEIGE_F5F5DC: Final[Color] = _F5F5DC
    CORNSILK_FFF8DC: Final[Color] = _FFF8DC
    BLONDE_FBF6D9: Final[Color] = _FBF6D9
    CHAMPAGNE_F7E7CE: Final[Color] = _F7E7CE
    ANTIQUE_WHITE_FAEBD7: Final[Color] = _FAEBD7
    PAPAYA_WHIP_FFEFD5: Final[Color] = _FFEFD5
    BLANCHED_ALMOND_FFEBCD: Final[Color] = _FFEBCD
    BISQUE_FFE4C4: Final[Color] = _FFE4C4
    WHEAT_F5DEB3: Final[Color] = _F5DEB3
    MOCCASIN_FFE4B5: Final[Color] = _FFE4B5
    PEACH_FFE5B4: Final[Color] = _FFE5B4
    LIGHT_ORANGE_FED8B1: Final[Color] = _FED8B1
    PEACH_PUFF_FFDAB9: Final[Color] = _FFDAB9
    CORAL_PEACH_FBD5AB: Final[Color] = _FBD5AB
    NAVAJO_WHITE_FFDEAD: Final[Color] = _FFDEAD
    GOLDEN_BLONDE_FBE7A1: Final[Color] = _FBE7A1
    GOLDEN_SILK_F3E3C3: Final[Color] = _F3E3C3
    DARK_BLONDE_F0E2B6: Final[Color] = _F0E2B6
    LIGHT_GOLD_F1E5AC: Final[Color] = _F1E5AC
    VANILLA_F3E5AB: Final[Color] = _F3E5AB
    TAN_BROWN_ECE5B6: Final[Color] = _ECE5B6
    DIRTY_WHITE_E8E4C9: Final[Color] = _E8E4C9
    PALE_GOLDEN_ROD_EEE8AA: Final[Color] = _EEE8AA
    KHAKI_F0E68C: Final[Color] = _F0E68C
    CARDBOARD_BROWN_EDDA74: Final[Color] = _EDDA74
    HARVEST_GOLD_EDE275: Final[Color] = _EDE275
    SUN_YELLOW_FFE87C: Final[Color] = _FFE87C
    CORN_YELLOW_FFF380: Final[Color] = _FFF380
    PASTEL_YELLOW_FAF884: Final[Color] = _FAF884
    NEON_YELLOW_FFFF33: Final[Color] = _FFFF33
    YELLOW_FFFF00: Final[Color] = _FFFF00
    CANARY_YELLOW_FFEF00: Final[Color] = _FFEF00
    BANANA_YELLOW_F5E216: Final[Color] = _F5E216
    MUSTARD_YELLOW_FFDB58: Final[Color] = _FFDB58
    GOLDEN_YELLOW_FFDF00: Final[Color] = _FFDF00
    BOLD_YELLOW_F9DB24: Final[Color] = _F9DB24
    RUBBER_DUCKY_YELLOW_FFD801: Final[Color] = _FFD801
    BRIGHT_GOLD_FDD017: Final[Color] = _FDD017
    CHROME_GOLD_FFCE44: Final[Color] = _FFCE44
    GOLDEN_BROWN_EAC117: Final[Color] = _EAC117
    DEEP_YELLOW_F6BE00: Final[Color] = _F6BE00
    MACARONI_AND_CHEESE_F2BB66: Final[Color] = _F2BB66
    SAFFRON_FBB917: Final[Color] = _FBB917
    NEON_GOLD_FDBD01: Final[Color] = _FDBD01
    BEER_FBB117: Final[Color] = _FBB117
    YELLOW_ORANGE_FFAE42: Final[Color] = _FFAE42
    CANTALOUPE_FFA62F: Final[Color] = _FFA62F
    CHEESE_ORANGE_FFA600: Final[Color] = _FFA600
    ORANGE_FFA500: Final[Color] = _FFA500
    BROWN_SAND_EE9A4D: Final[Color] = _EE9A4D
    SANDY_BROWN_F4A460: Final[Color] = _F4A460
    BROWN_SUGAR_E2A76F: Final[Color] = _E2A76F
    CAMEL_BROWN_C19A6B: Final[Color] = _C19A6B
    DEER_BROWN_E6BF83: Final[Color] = _E6BF83
    BURLY_WOOD_DEB887: Final[Color] = _DEB887
    TAN_D2B48C: Final[Color] = _D2B48C
    LIGHT_FRENCH_BEIGE_C8AD7F: Final[Color] = _C8AD7F
    SAGE_BCB88A: Final[Color] = _BCB88A
    FALL_LEAF_BROWN_C8B560: Final[Color] = _C8B560
    GINGER_BROWN_C9BE62: Final[Color] = _C9BE62
    BRONZE_GOLD_C9AE5D: Final[Color] = _C9AE5D
    DARK_KHAKI_BDB76B: Final[Color] = _BDB76B
    OLIVE_GREEN_BAB86C: Final[Color] = _BAB86C
    BRASS_B5A642: Final[Color] = _B5A642
    COOKIE_BROWN_C7A317: Final[Color] = _C7A317
    METALLIC_GOLD_D4AF37: Final[Color] = _D4AF37
    BEE_YELLOW_E9AB17: Final[Color] = _E9AB17
    SCHOOL_BUS_YELLOW_E8A317: Final[Color] = _E8A317
    GOLDENROD_DAA520: Final[Color] = _DAA520
    ORANGE_GOLD_D4A017: Final[Color] = _D4A017
    CARAMEL_C68E17: Final[Color] = _C68E17
    DARK_GOLDEN_ROD_B8860B: Final[Color] = _B8860B
    CINNAMON_C58917: Final[Color] = _C58917
    PERU_CD853F: Final[Color] = _CD853F
    BRONZE_CD7F32: Final[Color] = _CD7F32
    TIGER_ORANGE_C88141: Final[Color] = _C88141
    COPPER_B87333: Final[Color] = _B87333
    DARK_GOLD_AA6C39: Final[Color] = _AA6C39
    METALLIC_BRONZE_A97142: Final[Color] = _A97142
    DARK_ALMOND_AB784E: Final[Color] = _AB784E
    WOOD_966F33: Final[Color] = _966F33
    OAK_BROWN_806517: Final[Color] = _806517
    ANTIQUE_BRONZE_665D1E: Final[Color] = _665D1E
    HAZEL_8E7618: Final[Color] = _8E7618
    DARK_YELLOW_8B8000: Final[Color] = _8B8000
    DARK_MOCCASIN_827839: Final[Color] = _827839
    KHAKI_GREEN_8A865D: Final[Color] = _8A865D
    MILLENNIUM_JADE_93917C: Final[Color] = _93917C
    DARK_BEIGE_9F8C76: Final[Color] = _9F8C76
    BULLET_SHELL_AF9B60: Final[Color] = _AF9B60
    ARMY_BROWN_827B60: Final[Color] = _827B60
    SANDSTONE_786D5F: Final[Color] = _786D5F
    TAUPE_483C32: Final[Color] = _483C32
    MOCHA_493D26: Final[Color] = _493D26
    MILK_CHOCOLATE_513B1C: Final[Color] = _513B1C
    GRAY_BROWN_3D3635: Final[Color] = _3D3635
    DARK_COFFEE_3B2F2F: Final[Color] = _3B2F2F
    WESTERN_CHARCOAL_49413F: Final[Color] = _49413F
    OLD_BURGUNDY_43302E: Final[Color] = _43302E
    RED_BROWN_622F22: Final[Color] = _622F22
    BAKERS_BROWN_5C3317: Final[Color] = _5C3317
    DARK_BROWN_654321: Final[Color] = _654321
    SEPIA_BROWN_704214: Final[Color] = _704214
    DARK_BRONZE_804A00: Final[Color] = _804A00
    COFFEE_6F4E37: Final[Color] = _6F4E37
    BROWN_BEAR_835C3B: Final[Color] = _835C3B
    RED_DIRT_7F5217: Final[Color] = _7F5217
    SEPIA_7F462C: Final[Color] = _7F462C
    SIENNA_A0522D: Final[Color] = _A0522D
    SADDLE_BROWN_8B4513: Final[Color] = _8B4513
    DARK_SIENNA_8A4117: Final[Color] = _8A4117
    SANGRIA_7E3817: Final[Color] = _7E3817
    BLOOD_RED_7E3517: Final[Color] = _7E3517
    CHESTNUT_954535: Final[Color] = _954535
    CORAL_BROWN_9E4638: Final[Color] = _9E4638
    CHESTNUT_RED_C34A2C: Final[Color] = _C34A2C
    MAHOGANY_C04000: Final[Color] = _C04000
    RED_GOLD_EB5406: Final[Color] = _EB5406
    RED_FOX_C35817: Final[Color] = _C35817
    DARK_BISQUE_B86500: Final[Color] = _B86500
    LIGHT_BROWN_B5651D = _B5651D
    PETRA_GOLD_B76734: Final[Color] = _B76734
    RUST_C36241: Final[Color] = _C36241
    COPPER_RED_CB6D51: Final[Color] = _CB6D51
    ORANGE_SALMON_C47451: Final[Color] = _C47451
    CHOCOLATE_D2691E: Final[Color] = _D2691E
    SEDONA_CC6600: Final[Color] = _CC6600
    PAPAYA_ORANGE_E56717: Final[Color] = _E56717
    HALLOWEEN_ORANGE_E66C2C: Final[Color] = _E66C2C
    NEON_ORANGE_FF6700: Final[Color] = _FF6700
    BRIGHT_ORANGE_FF5F1F: Final[Color] = _FF5F1F
    PUMPKIN_ORANGE_F87217: Final[Color] = _F87217
    CARROT_ORANGE_F88017: Final[Color] = _F88017
    DARK_ORANGE_FF8C00: Final[Color] = _FF8C00
    CONSTRUCTION_CONE_ORANGE_F87431: Final[Color] = _F87431
    INDIAN_SAFFRON_FF7722: Final[Color] = _FF7722
    SUNRISE_ORANGE_E67451: Final[Color] = _E67451
    MANGO_ORANGE_FF8040: Final[Color] = _FF8040
    CORAL_FF7F50: Final[Color] = _FF7F50
    BASKET_BALL_ORANGE_F88158: Final[Color] = _F88158
    LIGHT_SALMON_ROSE_F9966B: Final[Color] = _F9966B
    LIGHT_SALMON_FFA07A: Final[Color] = _FFA07A
    PINK_ORANGE_F89880: Final[Color] = _F89880
    DARK_SALMON_E9967A: Final[Color] = _E9967A
    TANGERINE_E78A61: Final[Color] = _E78A61
    LIGHT_COPPER_DA8A67: Final[Color] = _DA8A67
    SALMON_PINK_FF8674: Final[Color] = _FF8674
    SALMON_FA8072: Final[Color] = _FA8072
    PEACH_PINK_F98B88: Final[Color] = _F98B88
    LIGHT_CORAL_F08080: Final[Color] = _F08080
    PASTEL_RED_F67280: Final[Color] = _F67280
    PINK_CORAL_E77471: Final[Color] = _E77471
    BEAN_RED_F75D59: Final[Color] = _F75D59
    VALENTINE_RED_E55451: Final[Color] = _E55451
    INDIAN_RED_CD5C5C: Final[Color] = _CD5C5C
    TOMATO_FF6347: Final[Color] = _FF6347
    SHOCKING_ORANGE_E55B3C: Final[Color] = _E55B3C
    ORANGE_RED_FF4500: Final[Color] = _FF4500
    RED_FF0000: Final[Color] = _FF0000
    NEON_RED_FD1C03: Final[Color] = _FD1C03
    SCARLET_RED_FF2400: Final[Color] = _FF2400
    RUBY_RED_F62217: Final[Color] = _F62217
    FIRE_ENGINE_RED_F62817: Final[Color] = _F62817
    LAVA_RED_E42217: Final[Color] = _E42217
    LOVE_RED_E41B17: Final[Color] = _E41B17
    GRAPEFRUIT_DC381F: Final[Color] = _DC381F
    CHERRY_RED_C24641: Final[Color] = _C24641
    CHILLI_PEPPER_C11B17: Final[Color] = _C11B17
    FIRE_BRICK_B22222: Final[Color] = _B22222
    TOMATO_SAUCE_RED_B21807: Final[Color] = _B21807
    BROWN_A52A2A: Final[Color] = _A52A2A
    CARBON_RED_A70D2A: Final[Color] = _A70D2A
    CRANBERRY_9F000F: Final[Color] = _9F000F
    SAFFRON_RED_931314: Final[Color] = _931314
    CRIMSON_RED_990000: Final[Color] = _990000
    RED_WINE_990012: Final[Color] = _990012
    DARK_RED_8B0000: Final[Color] = _8B0000
    MAROON_RED_8F0B0B: Final[Color] = _8F0B0B
    MAROON_800000: Final[Color] = _800000
    BURGUNDY_8C001A: Final[Color] = _8C001A
    VERMILION_7E191B: Final[Color] = _7E191B
    DEEP_RED_800517: Final[Color] = _800517
    GARNET_RED_733635: Final[Color] = _733635
    RED_BLOOD_660000: Final[Color] = _660000
    BLOOD_NIGHT_551606: Final[Color] = _551606
    DARK_SCARLET_560319: Final[Color] = _560319
    CHOCOLATE_BROWN_3F000F: Final[Color] = _3F000F
    BLACK_BEAN_3D0C02: Final[Color] = _3D0C02
    DARK_MAROON_2F0909: Final[Color] = _2F0909
    MIDNIGHT_2B1B17: Final[Color] = _2B1B17
    PURPLE_LILY_550A35: Final[Color] = _550A35
    PURPLE_MAROON_810541: Final[Color] = _810541
    PLUM_PIE_7D0541: Final[Color] = _7D0541
    PLUM_VELVET_7D0552: Final[Color] = _7D0552
    DARK_RASPBERRY_872657: Final[Color] = _872657
    VELVET_MAROON_7E354D: Final[Color] = _7E354D
    ROSY_FINCH_7F4E52: Final[Color] = _7F4E52
    DULL_PURPLE_7F525D: Final[Color] = _7F525D
    PUCE_7F5A58: Final[Color] = _7F5A58
    ROSE_DUST_997070: Final[Color] = _997070
    PASTEL_BROWN_B1907F: Final[Color] = _B1907F
    ROSY_PINK_B38481: Final[Color] = _B38481
    ROSY_BROWN_BC8F8F: Final[Color] = _BC8F8F
    KHAKI_ROSE_C5908E: Final[Color] = _C5908E
    LIPSTICK_PINK_C48793: Final[Color] = _C48793
    DUSKY_PINK_CC7A8B: Final[Color] = _CC7A8B
    PINK_BROWN_C48189: Final[Color] = _C48189
    OLD_ROSE_C08081: Final[Color] = _C08081
    DUSTY_PINK_D58A94: Final[Color] = _D58A94
    PINK_DAISY_E799A3: Final[Color] = _E799A3
    ROSE_E8ADAA: Final[Color] = _E8ADAA
    DUSTY_ROSE_C9A9A6: Final[Color] = _C9A9A6
    GOLD_PINK_E6C7C2: Final[Color] = _E6C7C2
    ROSE_GOLD_ECC5C0: Final[Color] = _ECC5C0
    DEEP_PEACH_FFCBA4: Final[Color] = _FFCBA4
    PASTEL_ORANGE_F8B88B: Final[Color] = _F8B88B
    DESERT_SAND_EDC9AF: Final[Color] = _EDC9AF
    UNBLEACHED_SILK_FFDDCA: Final[Color] = _FFDDCA
    PIG_PINK_FDD7E4: Final[Color] = _FDD7E4
    PALE_PINK_F2D4D7: Final[Color] = _F2D4D7
    BLUSH_FFE6E8: Final[Color] = _FFE6E8
    MISTY_ROSE_FFE4E1: Final[Color] = _FFE4E1
    PINK_BUBBLE_GUM_FFDFDD: Final[Color] = _FFDFDD
    LIGHT_ROSE_FBCFCD: Final[Color] = _FBCFCD
    LIGHT_RED_FFCCCB: Final[Color] = _FFCCCB
    WARM_PINK_F6C6BD: Final[Color] = _F6C6BD
    DEEP_ROSE_FBBBB9: Final[Color] = _FBBBB9
    PINK_FFC0CB: Final[Color] = _FFC0CB
    LIGHT_PINK_FFB6C1: Final[Color] = _FFB6C1
    SOFT_PINK_FFB8BF: Final[Color] = _FFB8BF
    POWDER_PINK_FFB2D0: Final[Color] = _FFB2D0
    DONUT_PINK_FAAFBE: Final[Color] = _FAAFBE
    BABY_PINK_FAAFBA: Final[Color] = _FAAFBA
    FLAMINGO_PINK_F9A7B0: Final[Color] = _F9A7B0
    PASTEL_PINK_FEA3AA: Final[Color] = _FEA3AA
    ROSE_PINK_E7A1B0: Final[Color] = _E7A1B0
    CADILLAC_PINK_E38AAE: Final[Color] = _E38AAE
    CARNATION_PINK_F778A1: Final[Color] = _F778A1
    PASTEL_ROSE_E5788F: Final[Color] = _E5788F
    BLUSH_RED_E56E94: Final[Color] = _E56E94
    PALE_VIOLET_RED_DB7093: Final[Color] = _DB7093
    PURPLE_PINK_D16587: Final[Color] = _D16587
    TULIP_PINK_C25A7C: Final[Color] = _C25A7C
    BASHFUL_PINK_C25283: Final[Color] = _C25283
    DARK_PINK_E75480: Final[Color] = _E75480
    DARK_HOT_PINK_F660AB: Final[Color] = _F660AB
    HOT_PINK_FF69B4: Final[Color] = _FF69B4
    WATERMELON_PINK_FC6C85: Final[Color] = _FC6C85
    VIOLET_RED_F6358A: Final[Color] = _F6358A
    HOT_DEEP_PINK_F52887: Final[Color] = _F52887
    BRIGHT_PINK_FF007F: Final[Color] = _FF007F
    DEEP_PINK_FF1493: Final[Color] = _FF1493
    NEON_PINK_F535AA: Final[Color] = _F535AA
    CHROME_PINK_FF33AA: Final[Color] = _FF33AA
    NEON_HOT_PINK_FD349C: Final[Color] = _FD349C
    PINK_CUPCAKE_E45E9D: Final[Color] = _E45E9D
    ROYAL_PINK_E759AC: Final[Color] = _E759AC
    DIMORPHOTHECA_MAGENTA_E3319D: Final[Color] = _E3319D
    PINK_LEMONADE_E4287C: Final[Color] = _E4287C
    RED_PINK_FA2A55: Final[Color] = _FA2A55
    RASPBERRY_E30B5D: Final[Color] = _E30B5D
    CRIMSON_DC143C: Final[Color] = _DC143C
    BRIGHT_MAROON_C32148: Final[Color] = _C32148
    ROSE_RED_C21E56: Final[Color] = _C21E56
    ROGUE_PINK_C12869: Final[Color] = _C12869
    BURNT_PINK_C12267: Final[Color] = _C12267
    PINK_VIOLET_CA226B: Final[Color] = _CA226B
    MAGENTA_PINK_CC338B: Final[Color] = _CC338B
    MEDIUM_VIOLET_RED_C71585: Final[Color] = _C71585
    DARK_CARNATION_PINK_C12283: Final[Color] = _C12283
    RASPBERRY_PURPLE_B3446C: Final[Color] = _B3446C
    PINK_PLUM_B93B8F: Final[Color] = _B93B8F
    ORCHID_DA70D6: Final[Color] = _DA70D6
    DEEP_MAUVE_DF73D4: Final[Color] = _DF73D4
    VIOLET_EE82EE: Final[Color] = _EE82EE
    FUCHSIA_PINK_FF77FF: Final[Color] = _FF77FF
    BRIGHT_NEON_PINK_F433FF: Final[Color] = _F433FF
    MAGENTA_FF00FF: Final[Color] = _FF00FF
    CRIMSON_PURPLE_E238EC: Final[Color] = _E238EC
    HELIOTROPE_PURPLE_D462FF: Final[Color] = _D462FF
    TYRIAN_PURPLE_C45AEC: Final[Color] = _C45AEC
    MEDIUM_ORCHID_BA55D3: Final[Color] = _BA55D3
    PURPLE_FLOWER_A74AC7: Final[Color] = _A74AC7
    ORCHID_PURPLE_B048B5: Final[Color] = _B048B5
    RICH_LILAC_B666D2: Final[Color] = _B666D2
    PASTEL_VIOLET_D291BC: Final[Color] = _D291BC
    MAUVE_TAUPE_915F6D: Final[Color] = _915F6D
    VIOLA_PURPLE_7E587E: Final[Color] = _7E587E
    EGGPLANT_614051: Final[Color] = _614051
    PLUM_PURPLE_583759: Final[Color] = _583759
    GRAPE_5E5A80: Final[Color] = _5E5A80
    PURPLE_NAVY_4E5180: Final[Color] = _4E5180
    SLATEBLUE_6A5ACD: Final[Color] = _6A5ACD
    BLUE_LOTUS_6960EC: Final[Color] = _6960EC
    BLURPLE_5865F2: Final[Color] = _5865F2
    LIGHT_SLATE_BLUE_736AFF: Final[Color] = _736AFF
    MEDIUM_SLATE_BLUE_7B68EE: Final[Color] = _7B68EE
    PERIWINKLE_PURPLE_7575CF: Final[Color] = _7575CF
    VERY_PERI_6667AB: Final[Color] = _6667AB
    BRIGHT_GRAPE_6F2DA8: Final[Color] = _6F2DA8
    PURPLE_AMETHYST_6C2DC7: Final[Color] = _6C2DC7
    BRIGHT_PURPLE_6A0DAD: Final[Color] = _6A0DAD
    DEEP_PERIWINKLE_5453A6: Final[Color] = _5453A6
    DARK_SLATE_BLUE_483D8B: Final[Color] = _483D8B
    PURPLE_HAZE_4E387E: Final[Color] = _4E387E
    PURPLE_IRIS_571B7E: Final[Color] = _571B7E
    DARK_PURPLE_4B0150: Final[Color] = _4B0150
    DEEP_PURPLE_36013F: Final[Color] = _36013F
    MIDNIGHT_PURPLE_2E1A47: Final[Color] = _2E1A47
    INDIGO_4B0082: Final[Color] = _4B0082
    BLUE_WHALE_342D7E: Final[Color] = _342D7E
    REBECCA_PURPLE_663399: Final[Color] = _663399
    PURPLE_JAM_6A287E: Final[Color] = _6A287E
    DARK_MAGENTA_8B008B: Final[Color] = _8B008B
    PURPLE_800080: Final[Color] = _800080
    FRENCH_LILAC_86608E: Final[Color] = _86608E
    DARK_ORCHID_9932CC: Final[Color] = _9932CC
    DARKVIOLET_9400D3: Final[Color] = _9400D3
    PURPLE_VIOLET_8D38C9: Final[Color] = _8D38C9
    JASMINE_PURPLE_A23BEC: Final[Color] = _A23BEC
    PURPLE_DAFFODIL_B041FF: Final[Color] = _B041FF
    CLEMATIS_VIOLET_842DCE: Final[Color] = _842DCE
    BLUE_VIOLET_8A2BE2: Final[Color] = _8A2BE2
    PURPLE_SAGE_BUSH_7A5DC7: Final[Color] = _7A5DC7
    LOVELY_PURPLE_7F38EC: Final[Color] = _7F38EC
    NEON_PURPLE_9D00FF: Final[Color] = _9D00FF
    PURPLE_PLUM_8E35EF: Final[Color] = _8E35EF
    AZTECH_PURPLE_893BFF: Final[Color] = _893BFF
    MEDIUM_PURPLE_9370DB: Final[Color] = _9370DB
    LIGHT_PURPLE_8467D7: Final[Color] = _8467D7
    CROCUS_PURPLE_9172EC: Final[Color] = _9172EC
    PURPLE_MIMOSA_9E7BFF: Final[Color] = _9E7BFF
    PERIWINKLE_CCCCFF: Final[Color] = _CCCCFF
    PALE_LILAC_DCD0FF: Final[Color] = _DCD0FF
    LAVENDER_PURPLE_967BB6: Final[Color] = _967BB6
    ROSE_PURPLE_B09FCA: Final[Color] = _B09FCA
    LILAC_C8A2C8: Final[Color] = _C8A2C8
    MAUVE_E0B0FF: Final[Color] = _E0B0FF
    BRIGHT_LILAC_D891EF: Final[Color] = _D891EF
    PURPLE_DRAGON_C38EC7: Final[Color] = _C38EC7
    PLUM_DDA0DD: Final[Color] = _DDA0DD
    BLUSH_PINK_E6A9EC: Final[Color] = _E6A9EC
    PASTEL_PURPLE_F2A2E8: Final[Color] = _F2A2E8
    BLOSSOM_PINK_F9B7FF: Final[Color] = _F9B7FF
    WISTERIA_PURPLE_C6AEC7: Final[Color] = _C6AEC7
    PURPLE_THISTLE_D2B9D3: Final[Color] = _D2B9D3
    THISTLE_D8BFD8: Final[Color] = _D8BFD8
    PURPLE_WHITE_DFD3E3: Final[Color] = _DFD3E3
    PERIWINKLE_PINK_E9CFEC: Final[Color] = _E9CFEC
    COTTON_CANDY_FCDFFF: Final[Color] = _FCDFFF
    LAVENDER_PINOCCHIO_EBDDE2: Final[Color] = _EBDDE2
    DARK_WHITE_E1D9D1: Final[Color] = _E1D9D1
    ASH_WHITE_E9E4D4: Final[Color] = _E9E4D4
    WARM_WHITE_EFEBD8: Final[Color] = _EFEBD8
    SOFT_IVORY_FAF0DD: Final[Color] = _FAF0DD
    OFF_WHITE_F8F0E3: Final[Color] = _F8F0E3
    PEARL_WHITE_F8F6F0: Final[Color] = _F8F6F0
    RED_WHITE_F3E8EA: Final[Color] = _F3E8EA
    LAVENDER_BLUSH_FFF0F5: Final[Color] = _FFF0F5
    PEARL_FDEEF4: Final[Color] = _FDEEF4
    EGG_SHELL_FFF9E3: Final[Color] = _FFF9E3
    OLD_LACE_FEF0E3: Final[Color] = _FEF0E3
    WHITE_ICE_EAEEE9: Final[Color] = _EAEEE9
    LINEN_FAF0E6: Final[Color] = _FAF0E6
    SEA_SHELL_FFF5EE: Final[Color] = _FFF5EE
    BONE_WHITE_F9F6EE: Final[Color] = _F9F6EE
    RICE_FAF5EF: Final[Color] = _FAF5EF
    FLORAL_WHITE_FFFAF0: Final[Color] = _FFFAF0
    IVORY_FFFFF0: Final[Color] = _FFFFF0
    WHITE_GOLD_FFFFF4: Final[Color] = _FFFFF4
    LIGHT_WHITE_FFFFF7: Final[Color] = _FFFFF7
    WHITE_SMOKE_F5F5F5: Final[Color] = _F5F5F5
    COTTON_FBFBF9: Final[Color] = _FBFBF9
    SNOW_FFFAFA: Final[Color] = _FFFAFA
    MILK_WHITE_FEFCFF: Final[Color] = _FEFCFF
    HALF_WHITE_FFFEFA: Final[Color] = _FFFEFA


class MaterialDesignColors(GetColorsMenmbersMixIn):
    """
    Material design colors' constants.

    References
    ----------
    - Overview, Material Design
        - https://m3.material.io/styles/color/overview
    - Style, Material Design
        - https://m1.material.io/style/color.html#
    - MaterialDesignColors class
        - https://simon-ritchie.github.io/apysc/en/material_design_colors.html
    """

    RED_50_FFEBEE: Final[Color] = _FFEBEE
    RED_100_FFCDD2: Final[Color] = _FFCDD2
    RED_200_EF9A9A: Final[Color] = _EF9A9A
    RED_300_E57373: Final[Color] = _E57373
    RED_400_EF5350: Final[Color] = _EF5350
    RED_500_F44336: Final[Color] = _F44336
    RED_600_E53935: Final[Color] = _E53935
    RED_700_D32F2F: Final[Color] = _D32F2F
    RED_800_C62828: Final[Color] = _C62828
    RED_900_B71C1C: Final[Color] = _B71C1C
    RED_A100_FF8A80: Final[Color] = _FF8A80
    RED_A200_FF5252: Final[Color] = _FF5252
    RED_A400_FF1744: Final[Color] = _FF1744
    RED_A700_D50000: Final[Color] = _D50000
    PINK_50_FCE4EC: Final[Color] = _FCE4EC
    PINK_100_F8BBD0: Final[Color] = _F8BBD0
    PINK_200_F48FB1: Final[Color] = _F48FB1
    PINK_300_F06292: Final[Color] = _F06292
    PINK_400_EC407A: Final[Color] = _EC407A
    PINK_500_E91E63: Final[Color] = _E91E63
    PINK_600_D81B60: Final[Color] = _D81B60
    PINK_700_C2185B: Final[Color] = _C2185B
    PINK_800_AD1457: Final[Color] = _AD1457
    PINK_900_880E4F: Final[Color] = _880E4F
    PINK_A100_FF80AB: Final[Color] = _FF80AB
    PINK_A200_FF4081: Final[Color] = _FF4081
    PINK_A400_F50057: Final[Color] = _F50057
    PINK_A700_C51162: Final[Color] = _C51162
    PURPLE_50_F3E5F5: Final[Color] = _F3E5F5
    PURPLE_100_E1BEE7: Final[Color] = _E1BEE7
    PURPLE_200_CE93D8: Final[Color] = _CE93D8
    PURPLE_300_BA68C8: Final[Color] = _BA68C8
    PURPLE_400_AB47BC: Final[Color] = _AB47BC
    PURPLE_500_9C27B0: Final[Color] = _9C27B0
    PURPLE_600_8E24AA: Final[Color] = _8E24AA
    PURPLE_700_7B1FA2: Final[Color] = _7B1FA2
    PURPLE_800_6A1B9A: Final[Color] = _6A1B9A
    PURPLE_900_4A148C: Final[Color] = _4A148C
    PURPLE_A100_EA80FC: Final[Color] = _EA80FC
    PURPLE_A200_E040FB: Final[Color] = _E040FB
    PURPLE_A400_D500F9: Final[Color] = _D500F9
    PURPLE_A700_AA00FF: Final[Color] = _AA00FF
    DEEP_PURPLE_50_EDE7F6: Final[Color] = _EDE7F6
    DEEP_PURPLE_100_D1C4E9: Final[Color] = _D1C4E9
    DEEP_PURPLE_200_B39DDB: Final[Color] = _B39DDB
    DEEP_PURPLE_300_9575CD: Final[Color] = _9575CD
    DEEP_PURPLE_400_7E57C2: Final[Color] = _7E57C2
    DEEP_PURPLE_500_673AB7: Final[Color] = _673AB7
    DEEP_PURPLE_600_5E35B1: Final[Color] = _5E35B1
    DEEP_PURPLE_700_512DA8: Final[Color] = _512DA8
    DEEP_PURPLE_800_4527A0: Final[Color] = _4527A0
    DEEP_PURPLE_900_311B92: Final[Color] = _311B92
    DEEP_PURPLE_A100_B388FF: Final[Color] = _B388FF
    DEEP_PURPLE_A200_7C4DFF: Final[Color] = _7C4DFF
    DEEP_PURPLE_A400_651FFF: Final[Color] = _651FFF
    DEEP_PURPLE_A700_6200EA: Final[Color] = _6200EA
    INDIGO_50_E8EAF6: Final[Color] = _E8EAF6
    INDIGO_100_C5CAE9: Final[Color] = _C5CAE9
    INDIGO_200_9FA8DA: Final[Color] = _9FA8DA
    INDIGO_300_7986CB: Final[Color] = _7986CB
    INDIGO_400_5C6BC0: Final[Color] = _5C6BC0
    INDIGO_500_3F51B5: Final[Color] = _3F51B5
    INDIGO_600_3949AB: Final[Color] = _3949AB
    INDIGO_700_303F9F: Final[Color] = _303F9F
    INDIGO_800_283593: Final[Color] = _283593
    INDIGO_900_1A237E: Final[Color] = _1A237E
    INDIGO_A100_8C9EFF: Final[Color] = _8C9EFF
    INDIGO_A200_536DFE: Final[Color] = _536DFE
    INDIGO_A400_3D5AFE: Final[Color] = _3D5AFE
    INDIGO_A700_304FFE: Final[Color] = _304FFE
    BLUE_50_E3F2FD: Final[Color] = _E3F2FD
    BLUE_100_BBDEFB: Final[Color] = _BBDEFB
    BLUE_200_90CAF9: Final[Color] = _90CAF9
    BLUE_300_64B5F6: Final[Color] = _64B5F6
    BLUE_400_42A5F5: Final[Color] = _42A5F5
    BLUE_500_2196F3: Final[Color] = _2196F3
    BLUE_600_1E88E5: Final[Color] = _1E88E5
    BLUE_700_1976D2: Final[Color] = _1976D2
    BLUE_800_1565C0: Final[Color] = _1565C0
    BLUE_900_0D47A1: Final[Color] = _0D47A1
    BLUE_A100_82B1FF: Final[Color] = _82B1FF
    BLUE_A200_448AFF: Final[Color] = _448AFF
    BLUE_A400_2979FF: Final[Color] = _2979FF
    BLUE_A700_2962FF: Final[Color] = _2962FF
    LIGHT_BLUE_50_E1F5FE: Final[Color] = _E1F5FE
    LIGHT_BLUE_100_B3E5FC: Final[Color] = _B3E5FC
    LIGHT_BLUE_200_81D4FA: Final[Color] = _81D4FA
    LIGHT_BLUE_300_4FC3F7: Final[Color] = _4FC3F7
    LIGHT_BLUE_400_29B6F6: Final[Color] = _29B6F6
    LIGHT_BLUE_500_03A9F4: Final[Color] = _03A9F4
    LIGHT_BLUE_600_039BE5: Final[Color] = _039BE5
    LIGHT_BLUE_700_0288D1: Final[Color] = _0288D1
    LIGHT_BLUE_800_0277BD: Final[Color] = _0277BD
    LIGHT_BLUE_900_01579B: Final[Color] = _01579B
    LIGHT_BLUE_A100_80D8FF: Final[Color] = _80D8FF
    LIGHT_BLUE_A200_40C4FF: Final[Color] = _40C4FF
    LIGHT_BLUE_A400_00B0FF: Final[Color] = _00B0FF
    LIGHT_BLUE_A700_0091EA: Final[Color] = _0091EA
    CYAN_50_E0F7FA: Final[Color] = _E0F7FA
    CYAN_100_B2EBF2: Final[Color] = _B2EBF2
    CYAN_200_80DEEA: Final[Color] = _80DEEA
    CYAN_300_4DD0E1: Final[Color] = _4DD0E1
    CYAN_400_26C6DA: Final[Color] = _26C6DA
    CYAN_500_00BCD4: Final[Color] = _00BCD4
    CYAN_600_00ACC1: Final[Color] = _00ACC1
    CYAN_700_0097A7: Final[Color] = _0097A7
    CYAN_800_00838F: Final[Color] = _00838F
    CYAN_900_006064: Final[Color] = _006064
    CYAN_A100_84FFFF: Final[Color] = _84FFFF
    CYAN_A200_18FFFF: Final[Color] = _18FFFF
    CYAN_A400_00E5FF: Final[Color] = _00E5FF
    CYAN_A700_00B8D4: Final[Color] = _00B8D4
    TEAL_50_E0F2F1: Final[Color] = _E0F2F1
    TEAL_100_B2DFDB: Final[Color] = _B2DFDB
    TEAL_200_80CBC4: Final[Color] = _80CBC4
    TEAL_300_4DB6AC: Final[Color] = _4DB6AC
    TEAL_400_26A69A: Final[Color] = _26A69A
    TEAL_500_009688: Final[Color] = _009688
    TEAL_600_00897B: Final[Color] = _00897B
    TEAL_700_00796B: Final[Color] = _00796B
    TEAL_800_00695C: Final[Color] = _00695C
    TEAL_900_004D40: Final[Color] = _004D40
    TEAL_A100_A7FFEB: Final[Color] = _A7FFEB
    TEAL_A200_64FFDA: Final[Color] = _64FFDA
    TEAL_A400_1DE9B6: Final[Color] = _1DE9B6
    TEAL_A700_00BFA5: Final[Color] = _00BFA5
    GREEN_50_E8F5E9: Final[Color] = _E8F5E9
    GREEN_100_C8E6C9: Final[Color] = _C8E6C9
    GREEN_200_A5D6A7: Final[Color] = _A5D6A7
    GREEN_300_81C784: Final[Color] = _81C784
    GREEN_400_66BB6A: Final[Color] = _66BB6A
    GREEN_500_4CAF50: Final[Color] = _4CAF50
    GREEN_600_43A047: Final[Color] = _43A047
    GREEN_700_388E3C: Final[Color] = _388E3C
    GREEN_800_2E7D32: Final[Color] = _2E7D32
    GREEN_900_1B5E20: Final[Color] = _1B5E20
    GREEN_A100_B9F6CA: Final[Color] = _B9F6CA
    GREEN_A200_69F0AE: Final[Color] = _69F0AE
    GREEN_A400_00E676: Final[Color] = _00E676
    GREEN_A700_00C853: Final[Color] = _00C853
    LIGHT_GREEN_50_F1F8E9: Final[Color] = _F1F8E9
    LIGHT_GREEN_100_DCEDC8: Final[Color] = _DCEDC8
    LIGHT_GREEN_200_C5E1A5: Final[Color] = _C5E1A5
    LIGHT_GREEN_300_AED581: Final[Color] = _AED581
    LIGHT_GREEN_400_9CCC65: Final[Color] = _9CCC65
    LIGHT_GREEN_500_8BC34A: Final[Color] = _8BC34A
    LIGHT_GREEN_600_7CB342: Final[Color] = _7CB342
    LIGHT_GREEN_700_689F38: Final[Color] = _689F38
    LIGHT_GREEN_800_558B2F: Final[Color] = _558B2F
    LIGHT_GREEN_900_33691E: Final[Color] = _33691E
    LIGHT_GREEN_A100_CCFF90: Final[Color] = _CCFF90
    LIGHT_GREEN_A200_B2FF59: Final[Color] = _B2FF59
    LIGHT_GREEN_A400_76FF03: Final[Color] = _76FF03
    LIGHT_GREEN_A700_64DD17: Final[Color] = _64DD17
    LIME_50_F9FBE7: Final[Color] = _F9FBE7
    LIME_100_F0F4C3: Final[Color] = _F0F4C3
    LIME_200_E6EE9C: Final[Color] = _E6EE9C
    LIME_300_DCE775: Final[Color] = _DCE775
    LIME_400_D4E157: Final[Color] = _D4E157
    LIME_500_CDDC39: Final[Color] = _CDDC39
    LIME_600_C0CA33: Final[Color] = _C0CA33
    LIME_700_AFB42B: Final[Color] = _AFB42B
    LIME_800_9E9D24: Final[Color] = _9E9D24
    LIME_900_827717: Final[Color] = _827717
    LIME_A100_F4FF81: Final[Color] = _F4FF81
    LIME_A200_EEFF41: Final[Color] = _EEFF41
    LIME_A400_C6FF00: Final[Color] = _C6FF00
    LIME_A700_AEEA00: Final[Color] = _AEEA00
    YELLOW_50_FFFDE7: Final[Color] = _FFFDE7
    YELLOW_100_FFF9C4: Final[Color] = _FFF9C4
    YELLOW_200_FFF59D: Final[Color] = _FFF59D
    YELLOW_300_FFF176: Final[Color] = _FFF176
    YELLOW_400_FFEE58: Final[Color] = _FFEE58
    YELLOW_500_FFEB3B: Final[Color] = _FFEB3B
    YELLOW_600_FDD835: Final[Color] = _FDD835
    YELLOW_700_FBC02D: Final[Color] = _FBC02D
    YELLOW_800_F9A825: Final[Color] = _F9A825
    YELLOW_900_F57F17: Final[Color] = _F57F17
    YELLOW_A100_FFFF8D: Final[Color] = _FFFF8D
    YELLOW_A200_FFFF00: Final[Color] = _FFFF00
    YELLOW_A400_FFEA00: Final[Color] = _FFEA00
    YELLOW_A700_FFD600: Final[Color] = _FFD600
    AMBER_50_FFF8E1: Final[Color] = _FFF8E1
    AMBER_100_FFECB3: Final[Color] = _FFECB3
    AMBER_200_FFE082: Final[Color] = _FFE082
    AMBER_300_FFD54F: Final[Color] = _FFD54F
    AMBER_400_FFCA28: Final[Color] = _FFCA28
    AMBER_500_FFC107: Final[Color] = _FFC107
    AMBER_600_FFB300: Final[Color] = _FFB300
    AMBER_700_FFA000: Final[Color] = _FFA000
    AMBER_800_FF8F00: Final[Color] = _FF8F00
    AMBER_900_FF6F00: Final[Color] = _FF6F00
    AMBER_A100_FFE57F: Final[Color] = _FFE57F
    AMBER_A200_FFD740: Final[Color] = _FFD740
    AMBER_A400_FFC400: Final[Color] = _FFC400
    AMBER_A700_FFAB00: Final[Color] = _FFAB00
    ORANGE_50_FFF3E0: Final[Color] = _FFF3E0
    ORANGE_100_FFE0B2: Final[Color] = _FFE0B2
    ORANGE_200_FFCC80: Final[Color] = _FFCC80
    ORANGE_300_FFB74D: Final[Color] = _FFB74D
    ORANGE_400_FFA726: Final[Color] = _FFA726
    ORANGE_500_FF9800: Final[Color] = _FF9800
    ORANGE_600_FB8C00: Final[Color] = _FB8C00
    ORANGE_700_F57C00: Final[Color] = _F57C00
    ORANGE_800_EF6C00: Final[Color] = _EF6C00
    ORANGE_900_E65100: Final[Color] = _E65100
    ORANGE_A100_FFD180: Final[Color] = _FFD180
    ORANGE_A200_FFAB40: Final[Color] = _FFAB40
    ORANGE_A400_FF9100: Final[Color] = _FF9100
    ORANGE_A700_FF6D00: Final[Color] = _FF6D00
    DEEP_ORANGE_50_FBE9E7: Final[Color] = _FBE9E7
    DEEP_ORANGE_100_FFCCBC: Final[Color] = _FFCCBC
    DEEP_ORANGE_200_FFAB91: Final[Color] = _FFAB91
    DEEP_ORANGE_300_FF8A65: Final[Color] = _FF8A65
    DEEP_ORANGE_400_FF7043: Final[Color] = _FF7043
    DEEP_ORANGE_500_FF5722: Final[Color] = _FF5722
    DEEP_ORANGE_600_F4511E: Final[Color] = _F4511E
    DEEP_ORANGE_700_E64A19: Final[Color] = _E64A19
    DEEP_ORANGE_800_D84315: Final[Color] = _D84315
    DEEP_ORANGE_900_BF360C: Final[Color] = _BF360C
    DEEP_ORANGE_A100_FF9E80: Final[Color] = _FF9E80
    DEEP_ORANGE_A200_FF6E40: Final[Color] = _FF6E40
    DEEP_ORANGE_A400_FF3D00: Final[Color] = _FF3D00
    DEEP_ORANGE_A700_DD2C00: Final[Color] = _DD2C00
    BROWN_50_EFEBE9: Final[Color] = _EFEBE9
    BROWN_100_D7CCC8: Final[Color] = _D7CCC8
    BROWN_200_BCAAA4: Final[Color] = _BCAAA4
    BROWN_300_A1887F: Final[Color] = _A1887F
    BROWN_400_8D6E63: Final[Color] = _8D6E63
    BROWN_500_795548: Final[Color] = _795548
    BROWN_600_6D4C41: Final[Color] = _6D4C41
    BROWN_700_5D4037: Final[Color] = _5D4037
    BROWN_800_4E342E: Final[Color] = _4E342E
    BROWN_900_3E2723: Final[Color] = _3E2723
    GRAY_50_FAFAFA: Final[Color] = _FAFAFA
    GRAY_100_F5F5F5: Final[Color] = _F5F5F5
    GRAY_200_EEEEEE: Final[Color] = _EEEEEE
    GRAY_300_E0E0E0: Final[Color] = _E0E0E0
    GRAY_400_BDBDBD: Final[Color] = _BDBDBD
    GRAY_500_9E9E9E: Final[Color] = _9E9E9E
    GRAY_600_757575: Final[Color] = _757575
    GRAY_700_616161: Final[Color] = _616161
    GRAY_800_424242: Final[Color] = _424242
    GRAY_900_212121: Final[Color] = _212121
    BLUE_GRAY_50_ECEFF1: Final[Color] = _ECEFF1
    BLUE_GRAY_100_CFD8DC: Final[Color] = _CFD8DC
    BLUE_GRAY_200_B0BEC5: Final[Color] = _B0BEC5
    BLUE_GRAY_300_90A4AE: Final[Color] = _90A4AE
    BLUE_GRAY_400_78909C: Final[Color] = _78909C
    BLUE_GRAY_500_607D8B: Final[Color] = _607D8B
    BLUE_GRAY_600_546E7A: Final[Color] = _546E7A
    BLUE_GRAY_700_455A64: Final[Color] = _455A64
    BLUE_GRAY_800_37474F: Final[Color] = _37474F
    BLUE_GRAY_900_263238: Final[Color] = _263238
    BLACK_000000: Final[Color] = _000000
    WHITE_FFFFFF: Final[Color] = _FFFFFF



"""The class implementation for the `flight_land` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialFlightLandIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `flight_land` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><g><path d="M2.5,19h19v2h-19V19z M19.34,15.85c0.8,0.21,1.62-0.26,1.84-1.06c0.21-0.8-0.26-1.62-1.06-1.84l-5.31-1.42l-2.76-9.02 L10.12,2v8.28L5.15,8.95L4.22,6.63L2.77,6.24v5.17L19.34,15.85z"/></g></g></g></svg>'  # noqa



"""The class implementation for the outlined `snooze` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSnoozeOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `snooze` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M9 11h3.63L9 15.2V17h6v-2h-3.63L15 10.8V9H9v2zm7.056-7.654l1.282-1.535 4.607 3.85-1.28 1.54zM3.336 7.19l-1.28-1.536L6.662 1.81l1.28 1.536zM12 6c3.86 0 7 3.14 7 7s-3.14 7-7 7-7-3.14-7-7 3.14-7 7-7m0-2c-4.97 0-9 4.03-9 9s4.03 9 9 9 9-4.03 9-9-4.03-9-9-9z"/></svg>'  # noqa



"""The utility module for getting material design settings.
"""

from typing import Optional

from apysc._color.color import Color
from apysc._material_design.color.material_color_scheme import MaterialColorScheme
from apysc._material_design.color.material_color_scheme_names import MaterialColorNames
from apysc._material_design.color.material_color_scheme_samples import (
    MaterialColorSchemeSamples,
)
from apysc._type.array import Array
from apysc._type.string import String


class MaterialSettingsUtils:

    _fixed_color_scheme: MaterialColorScheme

    @classmethod
    def _initialize_fixed_color_scheme_if_not_initialized(cls) -> None:
        """
        Initialize the `_fixed_color_scheme` attribute
        if it has not been initialized yet.
        """
        if hasattr(cls, "_fixed_color_scheme"):
            return
        cls._fixed_color_scheme = (
            MaterialColorSchemeSamples.create_dark_color_scheme_sample_brown_1()
        )

    @classmethod
    def _set_color_scheme_value_and_append_expression(
        cls,
        *,
        color_scheme: Optional[MaterialColorScheme],
        color_name: MaterialColorNames,
        target_color: Color,
    ) -> None:
        """
        Set a color scheme value to the target color and append
        color-related expressions.

        Notes
        -----
        If the specified `color_scheme` is `None`, then this method
        will do nothing.

        Parameters
        ----------
        color_scheme : Optional[MaterialColorScheme]
            A target color scheme.
        color_name : MaterialColorNames
            A target color name (e.g., "primary").
        target_color : Color
            A target color.
        """
        from apysc._expression import expression_data_util

        if color_scheme is None:
            return

        schgeme_color: Color = getattr(color_scheme, color_name)
        expression_data_util.append_js_expression(
            expression=f"{target_color.variable_name} = "
            f"{schgeme_color.variable_name};"
        )
        target_color._value = schgeme_color._value

    @classmethod
    def _get_target_color_and_add_expressions_by_color_name(
        cls,
        *,
        color_name: MaterialColorNames,
        argument_color: Optional[Color],
    ) -> Color:
        """
        Get a target color and add expressions of the specified
        color name.

        Parameters
        ----------
        color_name : MaterialColorNames
            A target color name (e.g., "primary").
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target primary color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        from apysc._branch._elif import Elif
        from apysc._branch._else import Else
        from apysc._branch._if import If
        from apysc._material_design.color.material_color_scheme import (
            MaterialColorScheme,
        )
        from apysc._material_design.setting.material_settings import MaterialSettings
        from apysc._type.boolean import Boolean

        cls._initialize_fixed_color_scheme_if_not_initialized()

        if argument_color is not None:
            return argument_color

        target_color: Color = Color("#000000")
        current_color_scheme_is_light_color_scheme: Boolean = (
            MaterialSettings.current_color_scheme_is_light_color_scheme()
        )
        current_color_scheme_is_dark_color_scheme: Boolean = (
            MaterialSettings.current_color_scheme_is_dark_color_scheme()
        )
        with If(MaterialSettings.color_scheme_setting_is_enabled()):
            with If(current_color_scheme_is_light_color_scheme):
                color_scheme: Optional[MaterialColorScheme] = (
                    MaterialSettings.get_light_color_scheme()
                )
                cls._set_color_scheme_value_and_append_expression(
                    color_scheme=color_scheme,
                    color_name=color_name,
                    target_color=target_color,
                )

            with Elif(current_color_scheme_is_dark_color_scheme):
                color_scheme = MaterialSettings.get_dark_color_scheme()
                cls._set_color_scheme_value_and_append_expression(
                    color_scheme=color_scheme,
                    color_name=color_name,
                    target_color=target_color,
                )
        with Else():
            cls._set_color_scheme_value_and_append_expression(
                color_scheme=cls._fixed_color_scheme,
                color_name=color_name,
                target_color=target_color,
            )
        return target_color

    @classmethod
    def get_primary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a primary color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `primary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="primary",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_primary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `on_primary` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_primary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_primary",
            argument_color=argument_color,
        )

    @classmethod
    def get_secondary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a secondary color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `secondary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="secondary",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_secondary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `on_secondary` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_secondary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_secondary",
            argument_color=argument_color,
        )

    @classmethod
    def get_error_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an error color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `error` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="error",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_error_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `on_error` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_error` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_error",
            argument_color=argument_color,
        )

    @classmethod
    def get_surface(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a surface color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `surface` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="surface",
            argument_color=argument_color,
        )

    @classmethod
    def on_surface_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `on_surface` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_surface` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_surface",
            argument_color=argument_color,
        )

    @classmethod
    def get_primary_container_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a `primary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `primary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="primary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_primary_container_color(
        cls,
        *,
        argument_color: Optional[Color],
    ) -> Color:
        """
        Get an `on_primary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_primary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_primary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_secondary_container_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a `secondary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `secondary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="secondary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_secondary_container_color(
        cls, *, argument_color: Optional[Color]
    ) -> Color:
        """
        Get an `on_secondary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_secondary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_secondary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_tertiary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a `tertiary` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `tertiary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="tertiary",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_tertiary_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `on_tertiary` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_tertiary` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_tertiary",
            argument_color=argument_color,
        )

    @classmethod
    def get_tertiary_container_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get a `tertiary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `tertiary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="tertiary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_tertiary_container_color(
        cls,
        *,
        argument_color: Optional[Color],
    ) -> Color:
        """
        Get an `on_tertiary_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_tertiary_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_tertiary_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_error_container_color(
        cls,
        *,
        argument_color: Optional[Color],
    ) -> Color:
        """
        Get an `error_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `error_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="error_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_on_error_container_color(
        cls,
        *,
        argument_color: Optional[Color],
    ) -> Color:
        """
        Get an `on_error_container` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `on_error_container` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="on_error_container",
            argument_color=argument_color,
        )

    @classmethod
    def get_outline_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `outline` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `outline` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="outline",
            argument_color=argument_color,
        )

    @classmethod
    def get_outline_variant_color(cls, *, argument_color: Optional[Color]) -> Color:
        """
        Get an `outline_variant` color setting from a setting or argument.

        Parameters
        ----------
        argument_color : Optional[Color]
            A specified argument color.

        Returns
        -------
        target_color : Color
            A target `outline_variant` color.
            This value becomes according to the following priorities:
            1. If the `argument_color` is not the `None`,
                the return value becomes its argument.
            2. If a color scheme is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed color value.
        """
        return cls._get_target_color_and_add_expressions_by_color_name(
            color_name="outline_variant",
            argument_color=argument_color,
        )

    _fixed_font_family: Array[String]

    @classmethod
    def _initialize_fixed_font_family_if_not_initialized(cls) -> None:
        """
        Initialize the `_fixed_font_family` attribute
        if it has not been initialized yet.
        """
        if hasattr(cls, "_fixed_font_family"):
            return
        cls._fixed_font_family = Array(
            [
                String("Arial"),
                String("Helvetica"),
                String("Roboto"),
                String("sans-serif"),
            ]
        )

    @classmethod
    def get_font_family(
        cls,
        *,
        argument_font_family: Optional[Array[String]],
    ) -> Array[String]:
        """
        Get a font-family setting from a setting or argument.

        Parameters
        ----------
        argument_font_family : Optional[Array[String]]
            A specified argument font-family setting.

        Returns
        -------
        target_font_family : Array[String]
            A target font-family setting.
            This value becomes according to the following priorities:
            1. If the `argument_font_family` is not the `None`,
                the return value becomes its argument.
            2. If a font-family setting is set in the `MaterialSettings`,
                the return value becomes its setting.
            3. A fixed font-family value.
        """
        from apysc._material_design.setting.material_settings import MaterialSettings

        cls._initialize_fixed_font_family_if_not_initialized()

        if argument_font_family is not None:
            return argument_font_family

        target_font_family: Optional[Array[String]] = MaterialSettings.get_font_family()
        if target_font_family is not None:
            return target_font_family

        return cls._fixed_font_family.copy()



"""The mix-in class implementation for the `String`'s `upper` method.
"""

from typing import TYPE_CHECKING

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting

if TYPE_CHECKING:
    from apysc._type.string import String


class StringUpperMixIn:
    @final
    @add_debug_info_setting(module_name=__name__)
    def upper(self) -> "String":
        """
        Get a copied upper case string.

        Returns
        -------
        string : String
            A copied upper case string.

        References
        ----------
        - String class upper method
            - https://simon-ritchie.github.io/apysc/en/string_upper.html

        Examples
        --------
        >>> import apysc as ap
        >>> string: ap.String = ap.String("Hello")
        >>> string = string.upper()
        >>> string
        String("HELLO")
        """
        from apysc._expression import expression_data_util
        from apysc._type.string import String
        from apysc._validation import string_validation

        self_string: String = string_validation.validate_apysc_string_type(string=self)
        string: String = self_string.copy()
        string._value = string._value.upper()
        expression: str = (
            f"{string.variable_name} = {self_string.variable_name}.toUpperCase();"
        )
        expression_data_util.append_js_expression(expression=expression)
        return string
